// Sviluppato da Mauro Donati

/*  This file contains the spell information that will be analysed by the search engine. In case of changes to the
spell list in the site, it should be kept up-to-date in order to obtain correct information by the search engine.

The structure is an array of arrays of strings, each of the inner arrays contains data related to one spell.

var spelllist = new Array(
    new Array('Spell 1 name',       'School',     'Subschool', 'Descriptor',
              'Schools and Levels', 'Components', 'Link',      'Short description'),
    new Array('Spell 2 name',       'School',     'Subschool', 'Descriptor',
              'Schools and Levels', 'Components', 'Link',      'Short description'),
    ...
    new Array('Spell 98 name',      'School',     'Subschool', 'Descriptor',
              'Schools and Levels', 'Components', 'Link',      'Short description'),
    new Array('Spell 99 name',      'School',     'Subschool', 'Descriptor',
              'Schools and Levels', 'Components', 'Link',      'Short description')
);


The search engine will load the main array, check the search criteria row by row and print the spell if its row
matches every selected criterion; thus, it is important for the inner arrays to be alpha-sorted on the spell name
to obtain an alpha-sorted spell list.

Each of the inner arrays is composed by eigth string fields:
- Spell name (must be in alphabetical order)
- School: should correspond to the value of one option in the school select of the search page.
- Subschool: should correspond to the value of one option in the subschool select of the search page or be void.
- Descriptor list: should be a ', ' (comma and space) separated list of fields, each of them should correspond to
          the value of one option in the descriptor select of the search page. May be void
- Class/Level: sholud be a ', ' separated list of fields composed by a *word*, a ' ' (space) and a *number*.
          the *word* should correspond to the value of one option in the class select of the main page, the
          *number* - the level - should span from 0 to 9. At least a couple word-number is expected to be present.
- Component: sholud be a ', ' separated list of fields, each of them should correspond to the value of one option
          in the component select of the search page. At least one is expected to be present.
- Link: should be a valid link to the page containing the description of the spell, such as: 'spellsAtoB.html#name'
- Short Description: Short description of the spell like the one in the class spell lists.

Not too clear? Maybe the best examples are in the table itself!

Search is case-insensitive, but capital letters should be used in the right way to obtain a correct display.

*** please remember to escape the ' (single quotes) with '\' (backslash) in any fields (as in 'Bear\' Endurance'),
or it will lead to a JavaScript error.       */

var spelllist = new Array(
new Array('Acid Arrow', 'Conjuration', 'Creation', 'Acid', 'Sor/Wiz 2', 'V, S, M, F', 'spellsAtoB.html#acid-arrow', 'Ranged touch attack; 2d4 damage for 1 round +1 round/three levels.'),
new Array('Acid Fog', 'Conjuration', 'Creation', 'Acid', 'Sor/Wiz 6, Water 7', 'V, S, M/DF', 'spellsAtoB.html#acid-fog', 'Fog deals acid damage.'),
new Array('Acid Splash', 'Conjuration', 'Creation', 'Acid', 'Sor/Wiz 0', 'V, S', 'spellsAtoB.html#acid-splash', 'Orb deals 1d3 acid damage.'),
new Array('Aid', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Clr 2, Good 2, Luck 2', 'V, S, DF', 'spellsAtoB.html#aid', '+1 on attack rolls and saves against fear, 1d8 temporary hp +1/level (max +10).'),
new Array('Air Walk', 'Transmutation', '', 'Air', 'Air 4, Clr 4, Drd 4', 'V, S, DF', 'spellsAtoB.html#air-walk', 'Subject treads on air as if solid (climb at 45-degree angle).'),
new Array('Alarm', 'Abjuration', '', '', 'Brd 1, Rgr 1, Sor/Wiz 1', 'V, S, F/DF', 'spellsAtoB.html#alarm', 'Wards an area for 2 hours/level.'),
new Array('Align Weapon', 'Transmutation', '', 'see text', 'Clr 2', 'V, S, DF', 'spellsAtoB.html#align-weapon', 'Weapon becomes good, evil, lawful, or chaotic.'),
new Array('Alter Self', 'Transmutation', '', '', 'Brd 2, Sor/Wiz 2', 'V, S', 'spellsAtoB.html#alter-self', 'Assume form of a similar creature.'),
new Array('Analyze Dweomer', 'Divination', '', '', 'Brd 6, Sor/Wiz 6', 'V, S, F', 'spellsAtoB.html#analyze-dweomer', 'Reveals magical aspects of subject.'),
new Array('Animal Growth', 'Transmutation', '', '', 'Drd 5, Rgr 4, Sor/Wiz 5', 'V, S', 'spellsAtoB.html#animal-growth', 'One animal/two levels doubles in size.'),
new Array('Animal Messenger', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 2, Drd 2, Rgr 1', 'V, S, M', 'spellsAtoB.html#animal-messenger', 'Sends a Tiny animal to a specific place.'),
new Array('Animal Shapes', 'Transmutation', '', '', 'Animal 7, Drd 8', 'V, S, DF', 'spellsAtoB.html#animal-shapes', 'One ally/level polymorphs into chosen animal.'),
new Array('Animal Trance', 'Enchantment', 'Compulsion', 'Mind-Affecting, Sonic', 'Brd 2, Drd 2', 'V, S', 'spellsAtoB.html#animal-trance', 'Fascinates 2d6 HD of animals.'),
new Array('Animate Dead', 'Necromancy', '', 'Evil', 'Clr 3, Death 3, Sor/Wiz 4', 'V, S, M', 'spellsAtoB.html#animate-dead', 'Creates undead skeletons and zombies.'),
new Array('Animate Objects', 'Transmutation', '', '', 'Brd 6, Chaos 6, Clr 6', 'V, S', 'spellsAtoB.html#animate-objects', 'Objects attack your foes.'),
new Array('Animate Plants', 'Transmutation', '', '', 'Drd 7, Plant 7', 'V', 'spellsAtoB.html#animate-plants', 'One or more plants animate and fight for you.'),
new Array('Animate Rope', 'Transmutation', '', '', 'Brd 1, Sor/Wiz 1', 'V, S', 'spellsAtoB.html#animate-rope', 'Makes a rope move at your command.'),
new Array('Antilife Shell', 'Abjuration', '', '', 'Animal 6, Clr 6, Drd 6', 'V, S, DF', 'spellsAtoB.html#antilife-shell', '10-ft. field hedges out living creatures.'),
new Array('Antimagic Field', 'Abjuration', '', '', 'Clr 8, Magic 6, Protection 6, Sor/Wiz 6', 'V, S, M/DF', 'spellsAtoB.html#antimagic-field', 'Negates magic within 10 ft.'),
new Array('Antipathy', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Drd 9, Sor/Wiz 8', 'V, S, M/DF', 'spellsAtoB.html#antipathy', 'Object or location affected by spell repels certain creatures.'),
new Array('Antiplant Shell', 'Abjuration', '', '', 'Drd 4', 'V, S, DF', 'spellsAtoB.html#antiplant-shell', 'Keeps animated plants at bay.'),
new Array('Arcane Eye', 'Divination', 'Scrying', '', 'Sor/Wiz 4', 'V, S, M', 'spellsAtoB.html#arcane-eye', '<a href="#" onClick="openLink(\'abilitiesAndConditions.html#invisible\');return false" style="color: rgb(87, 158, 182);">Invisible</a> floating eye moves 30 ft./round.'),
new Array('Arcane Lock', 'Abjuration', '', '', 'Sor/Wiz 2', 'V, S, M', 'spellsAtoB.html#arcane-lock', 'Magically locks a portal or chest.'),
new Array('Arcane Mark', 'Universal', '', '', 'Sor/Wiz 0', 'V, S', 'spellsAtoB.html#arcane-mark', 'Inscribes a personal rune (visible or invisible).'),
new Array('Arcane Sight', 'Divination', '', '', 'Sor/Wiz 3', 'V, S', 'spellsAtoB.html#arcane-sight', 'Magical auras become visible to you.'),
new Array('Arcane Sight, Greater', 'Divination', '', '', 'Sor/Wiz 7', 'V, S', 'spellsAtoB.html#greater-arcane-sight', 'As arcane sight, but also reveals magic effects on creatures and objects.'),
new Array('Astral Projection', 'Necromancy', '', '', 'Clr 9, Sor/Wiz 9, Travel 9', 'V, S, M', 'spellsAtoB.html#astral-projection', 'Projects you and companions onto Astral Plane.'),
new Array('Atonement', 'Abjuration', '', '', 'Clr 5, Drd 5', 'V, S, M, F, DF, XP', 'spellsAtoB.html#atonement', 'Removes burden of misdeeds from subject.'),
new Array('Augury', 'Divination', '', '', 'Clr 2', 'V, S, M, F', 'spellsAtoB.html#augury', 'Learns whether an action will be good or bad.'),
new Array('Awaken', 'Transmutation', '', '', 'Drd 5', 'V, S, DF, XP', 'spellsAtoB.html#awaken', 'Animal or tree gains human intellect.'),
new Array('Baleful Polymorph', 'Transmutation', '', '', 'Drd 5, Sor/Wiz 5', 'V, S', 'spellsAtoB.html#baleful-polymorph', 'Transforms subject into harmless animal.'),
new Array('Bane', 'Enchantment', 'Compulsion', 'Fear, Mind-Affecting', 'Clr 1', 'V, S, DF', 'spellsAtoB.html#bane', 'Enemies take &#8211;1 on attack rolls and saves against fear.'),
new Array('Banishment', 'Abjuration', '', '', 'Clr 6, Sor/Wiz 7', 'V, S, F', 'spellsAtoB.html#banishment', 'Banishes 2 HD/level of extraplanar creatures.'),
new Array('Barkskin', 'Transmutation', '', '', 'Drd 2, Rgr 2, Plant 2', 'V, S, DF', 'spellsAtoB.html#barkskin', 'Grants +2 (or higher) enhancement to natural armor.'),
new Array('Bear\'s Endurance', 'Transmutation', '', '', 'Clr 2, Drd 2, Rgr 2, Sor/Wiz 2', 'V, S, DF', 'spellsAtoB.html#bears-endurance', 'Subject gains +4 to Con for 1 min./level.'),
new Array('Bear\'s Endurance, Mass', 'Transmutation', '', '', 'Clr 6, Drd 6, Sor/Wiz 6', 'V, S, DF', 'spellsAtoB.html#mass-bears-endurance', 'As bear&#8217;s endurance, affects one subject/level.'),
new Array('Bestow Curse', 'Necromancy', '', '', 'Clr 3, Sor/Wiz 4', 'V, S', 'spellsAtoB.html#bestow-curse', '&#8211;6 to an ability score; &#8211;4 on attack rolls, saves, and checks; or 50% chance of losing each action.'),
new Array('Binding', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Sor/Wiz 8', 'V, S, M', 'spellsAtoB.html#binding', 'Utilizes an array of techniques to imprison a creature.'),
new Array('Black Tentacles', 'Conjuration', 'Creation', '', 'Sor/Wiz 4', 'V, S, M', 'spellsAtoB.html#black-tentacles', 'Tentacles <a href="#" onClick="openLink(\'specialAttacks.html#grapple\');return false" style="color: rgb(87, 158, 182);">grapple</a> all within 15 ft. spread.'),
new Array('Blade Barrier', 'Evocation', '', 'Force', 'Clr 6, Good 6, War 6', 'V, S', 'spellsAtoB.html#blade-barrier', 'Wall of blades deals 1d6/level damage.'),
new Array('Blasphemy', 'Evocation', '', 'Evil, Sonic', 'Clr 7, Evil 7', 'V', 'spellsAtoB.html#blasphemy', 'Kills, paralyzes, weakens, or dazes nonevil subjects.'),
new Array('Bless', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Clr 1, Pal 1', 'V, S, DF', 'spellsAtoB.html#bless', 'Allies gain +1 on attack rolls and saves against fear.'),
new Array('Bless Water', 'Transmutation', '', 'Good', 'Clr 1, Pal 1', 'V, S, M', 'spellsAtoB.html#bless-water', 'Makes holy water.'),
new Array('Bless Weapon', 'Transmutation', '', '', 'Pal 1', 'V, S', 'spellsAtoB.html#bless-weapon', 'Weapon strikes true against evil foes.'),
new Array('Blight', 'Necromancy', '', '', 'Drd 4, Sor/Wiz 5', 'V, S, DF', 'spellsAtoB.html#blight', 'Withers one plant or deals 1d6/level damage to plant creature.'),
new Array('Blindness/Deafness', 'Necromancy', '', '', 'Brd 2, Clr 3, Sor/Wiz 2', 'V', 'spellsAtoB.html#blindness/deafness', 'Makes subject <a href="#" onClick="openLink(\'abilitiesAndConditions.html#blinded\');return false" style="color: rgb(87, 158, 182);">blinded</a> or <a href="#" onClick="openLink(\'abilitiesAndConditions.html#deafened\');return false" style="color: rgb(87, 158, 182);">deafened</a>.'),
new Array('Blink', 'Transmutation', '', '', 'Brd 3, Sor/Wiz 3', 'V, S', 'spellsAtoB.html#blink', 'You randomly vanish and reappear for 1 round/level.'),
new Array('Blur', 'Illusion', 'Glamer', '', 'Brd 2,Sor/Wiz 2', 'V', 'spellsAtoB.html#blur', 'Attacks miss subject 20% of the time.'),
new Array('Break Enchantment', 'Abjuration', '', '', 'Brd 4, Clr 5, Luck 5, Pal 4, Sor/Wiz 5', 'V, S', 'spellsAtoB.html#break-enchantment', 'Frees subjects from enchantments, alterations, curses, and petrification.'),
new Array('Bull\'s Strength', 'Transmutation', '', '', 'Clr 2, Drd 2, Pal 2, Sor/Wiz 2, Strength 2', 'V, S, M/DF', 'spellsAtoB.html#bulls-strength', 'Subject gains +4 to Str for 1 min./level.'),
new Array('Bull\'s Strength, Mass', 'Transmutation', '', '', 'Clr 6, Drd 6, Sor/Wiz 6', 'V, S, M/DF', 'spellsAtoB.html#mass-bulls-strength', 'As bull&#8217;s strength, affects one subject/ level.'),
new Array('Burning Hands', 'Evocation', '', 'Fire', 'Fire 1, Sor/Wiz 1', 'V, S', 'spellsAtoB.html#burning-hands', '1d4/level fire damage (max 5d4).'),
new Array('Call Lightning', 'Evocation', '', 'Electricity', 'Drd 3', 'V, S', 'spellsC.html#call-lightning', 'Calls down lightning bolts (3d6 per bolt) from sky.'),
new Array('Call Lightning Storm', 'Evocation', '', 'Electricity', 'Drd 5', 'V, S', 'spellsC.html#call-lightning-storm', 'As call lightning, but 5d6 damage per bolt.'),
new Array('Calm Animals', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Animal 1, Drd 1, Rgr 1', 'V, S', 'spellsC.html#calm-animals', 'Calms (2d4 + level) HD of animals.'),
new Array('Calm Emotions', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 2, Clr 2, Law 2', 'V, S, DF', 'spellsC.html#calm-emotions', 'Calms creatures, negating emotion effects.'),
new Array('Cat\'s Grace', 'Transmutation', '', '', 'Brd 2, Drd 2, Rgr 2, Sor/Wiz 2', 'V, S, M', 'spellsC.html#cats-grace', 'Subject gains +4 to Dex for 1 min./level.'),
new Array('Cat\'s Grace, Mass', 'Transmutation', '', '', 'Brd 6, Drd 6, Sor/Wiz 6', 'V, S, M', 'spellsC.html#mass-cats-grace', 'As cat&#8217;s grace, affects one subject/level.'),
new Array('Cause Fear', 'Necromancy', '', 'Fear, Mind-Affecting', 'Brd 1, Clr 1, Death 1, Sor/Wiz 1', 'V, S', 'spellsC.html#cause-fear', 'One creature of 5 HD or less flees for 1d4 rounds.'),
new Array('Chain Lightning', 'Evocation', '', 'Electricity', 'Air 6, Sor/Wiz 6', 'V, S, F', 'spellsC.html#chain-lightning', '1d6/level damage; 1 secondary bolt/level each deals half damage.'),
new Array('Changestaff', 'Transmutation', '', '', 'Drd 7', 'V, S, F', 'spellsC.html#changestaff', 'Your staff becomes a treant on command.'),
new Array('Chaos Hammer', 'Evocation', '', 'Chaotic', 'Chaos 4', 'V, S', 'spellsC.html#chaos-hammer', 'Damages and staggers lawful creatures.'),
new Array('Charm Animal', 'Enchantment', 'Charm', 'Mind-Affecting', 'Drd 1, Rgr 1', 'V, S', 'spellsC.html#charm-animal', 'Makes one animal your friend.'),
new Array('Charm Monster', 'Enchantment', 'Charm', 'Mind-Affecting', 'Brd 3, Sor/Wiz 4', 'V', 'spellsC.html#charm-monster', 'Makes monster believe it is your ally.'),
new Array('Charm Monster, Mass', 'Enchantment', 'Charm', 'Mind-Affecting', 'Brd 6, Sor/Wiz 8', 'V', 'spellsC.html#mass-charm-monster', 'As charm monster, but all within 30 ft.'),
new Array('Charm Person', 'Enchantment', 'Charm', 'Mind-Affecting', 'Brd 1, Sor/Wiz 1', 'V, S', 'spellsC.html#charm-person', 'Makes one person your friend.'),
new Array('Chill Metal', 'Transmutation', '', 'Cold', 'Drd 2', 'V, S, DF', 'spellsC.html#chill-metal', 'Cold metal damages those who touch it.'),
new Array('Chill Touch', 'Necromancy', '', '', 'Sor/Wiz 1', 'V, S', 'spellsC.html#chill-touch', 'One touch/level deals 1d6 damage and possibly 1 Str damage.'),
new Array('Circle of Death', 'Necromancy', '', 'Death', 'Sor/Wiz 6', 'V, S, M', 'spellsC.html#circle-of-death', 'Kills 1d4/level HD of creatures.'),
new Array('Clairaudience/Clairvoyance', 'Divination', 'Scrying', '', 'Brd 3, Knowledge 3, Sor/Wiz 3', 'V, S, F/DF', 'spellsC.html#clairaudience/clairvoyance', 'Hear or see at a distance for 1 min./level.'),
new Array('Clenched Fist', 'Evocation', '', 'Force', 'Sor/Wiz 8, Strength 8', 'V, S, F/DF', 'spellsC.html#clenched-fist', 'Large hand provides cover, pushes, or attacks your foes.'),
new Array('Cloak of Chaos', 'Abjuration', '', 'Chaotic', 'Chaos 8, Clr 8', 'V, S, F', 'spellsC.html#cloak-of-chaos', '+4 to AC, +4 resistance, and SR 25 against lawful spells.'),
new Array('Clone', 'Necromancy', '', '', 'Sor/Wiz 8', 'V, S, M, F', 'spellsC.html#clone', 'Duplicate awakens when original dies.'),
new Array('Cloudkill', 'Conjuration', 'Creation', '', 'Sor/Wiz 5', 'V, S', 'spellsC.html#cloudkill', 'Kills 3 HD or less; 4&#8211;6 HD save or die, 6+ HD take Con damage.'),
new Array('Color Spray', 'Illusion', 'Pattern', 'Mind-Affecting', 'Sor/Wiz 1', 'V, S, M', 'spellsC.html#color-spray', 'Knocks <a href="#" onClick="openLink(\'abilitiesAndConditions.html#unconscious\');return false" style="color: rgb(87, 158, 182);">unconscious</a>, <a href="#" onClick="openLink(\'abilitiesAndConditions.html#blinded\');return false" style="color: rgb(87, 158, 182);">blinds</a>, and/or <a href="#" onClick="openLink(\'abilitiesAndConditions.html#stunned\');return false" style="color: rgb(87, 158, 182);">stuns</a> 1d6 weak creatures.'),
new Array('Command', 'Enchantment', 'Compulsion', 'Language-Dependent, Mind-Affecting', 'Clr 1', 'V', 'spellsC.html#command', 'One subject obeys selected command for 1 round.'),
new Array('Command Plants', 'Transmutation', '', '', 'Drd 4, Plant 4, Rgr 3', 'V', 'spellsC.html#command-plants', 'Sway the actions of one or more plant creatures.'),
new Array('Command Undead', 'Necromancy', '', '', 'Sor/Wiz 2', 'V, S, M', 'spellsC.html#command-undead', 'Undead creature obeys your commands.'),
new Array('Command, Greater', 'Enchantment', 'Compulsion', 'Language-Dependent, Mind-Affecting', 'Clr 5', 'V', 'spellsC.html#greater-command', 'As command, but affects one subject/level.'),
new Array('Commune', 'Divination', '', '', 'Clr 5', 'V, S, M, DF, XP', 'spellsC.html#commune', 'Deity answers one yes-or-no question/level.'),
new Array('Commune with Nature', 'Divination', '', '', 'Animal 5, Drd 5, Rgr 4', 'V, S', 'spellsC.html#commune-with-nature', 'Learn about terrain for 1 mile/level.'),
new Array('Comprehend Languages', 'Divination', '', '', 'Brd 1, Clr 1, Sor/Wiz 1', 'V, S, M/DF', 'spellsC.html#comprehend-languages', 'You understand all spoken and written languages.'),
new Array('Cone of Cold', 'Evocation', '', 'Cold', 'Sor/Wiz 5, Water 6', 'V, S, M/DF', 'spellsC.html#cone-of-cold', '1d6/level cold damage.'),
new Array('Confusion', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 3, Sor/Wiz 4, Trickery 4', 'V, S, M/DF', 'spellsC.html#confusion', 'Subjects behave oddly for 1 round/level.'),
new Array('Confusion, Lesser', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 1', 'V, S, DF', 'spellsC.html#lesser-confusion', 'One creature is <a href="#" onClick="openLink(\'abilitiesAndConditions.html#confused\');return false" style="color: rgb(87, 158, 182);">confused</a> for 1 round.'),
new Array('Consecrate', 'Evocation', '', 'Good', 'Clr 2', 'V, S, M, DF', 'spellsC.html#consecrate', 'Fills area with positive energy, making undead weaker.'),
new Array('Contact Other Plane', 'Divination', '', '', 'Sor/Wiz 5', 'V', 'spellsC.html#contact-other-plane', 'Lets you ask question of extraplanar entity.'),
new Array('Contagion', 'Necromancy', '', 'Evil', 'Clr 3, Destruction 3, Drd 3, Sor/Wiz 4', 'V, S', 'spellsC.html#contagion', 'Infects subject with chosen disease.'),
new Array('Contingency', 'Evocation', '', '', 'Sor/Wiz 6', 'V, S, M, F', 'spellsC.html#contingency', 'Sets trigger condition for another spell.'),
new Array('Continual Flame', 'Evocation', '', 'Light', 'Clr 3, Sor/Wiz 2', 'V, S, M', 'spellsC.html#continual-flame', 'Makes a permanent, heatless torch.'),
new Array('Control Plants', 'Transmutation', '', '', 'Drd 8, Plant 8', 'V, S, DF', 'spellsC.html#control-plants', 'Control actions of one or more plant creatures.'),
new Array('Control Undead', 'Necromancy', '', '', 'Sor/Wiz 7', 'V, S, M', 'spellsC.html#control-undead', 'Undead don&#8217;t attack you while under your command.'),
new Array('Control Water', 'Transmutation', '', 'Water', 'Clr 4, Drd 4, Sor/Wiz 6, Water 4', 'V, S, M/DF', 'spellsC.html#control-water', 'Raises or lowers bodies of water.'),
new Array('Control Weather', 'Transmutation', '', '', 'Air 7, Clr 7, Drd 7, Sor/Wiz 7', 'V, S', 'spellsC.html#control-weather', 'Changes weather in local area.'),
new Array('Control Winds', 'Transmutation', '', 'Air', 'Air 5, Drd 5', 'V, S', 'spellsC.html#control-winds', 'Change wind direction and speed.'),
new Array('Create Food and Water', 'Conjuration', 'Creation', '', 'Clr 3', 'V, S', 'spellsC.html#create-food-and-water', 'Feeds three humans (or one horse)/level.'),
new Array('Create Greater Undead', 'Necromancy', '', 'Evil', 'Clr 8, Death 8, Sor/Wiz 8', 'V, S, M', 'spellsC.html#create-greater-undead', 'Create shadows, wraiths, spectres, or devourers.'),
new Array('Create Undead', 'Necromancy', '', 'Evil', 'Clr 6, Death 6, Evil 6, Sor/Wiz 6', 'V, S, M', 'spellsC.html#create-undead', 'Creates ghouls, ghasts, mummies, or mohrgs.'),
new Array('Create Water', 'Conjuration', 'Creation', 'Water', 'Clr 0, Drd 0, Pal 1', 'V, S', 'spellsC.html#create-water', 'Creates 2 gallons/level of pure water.'),
new Array('Creeping Doom', 'Conjuration', 'Summoning', '', 'Drd 7', 'V, S', 'spellsC.html#creeping-doom', 'Swarms of centipedes attack at your command.'),
new Array('Crushing Despair', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 3, Sor/Wiz 4', 'V, S, M', 'spellsC.html#crushing-despair', 'Subjects take &#8211;2 on attack rolls, damage rolls, saves, and checks.'),
new Array('Crushing Hand', 'Evocation', '', 'Force', 'Sor/Wiz 9, Strength 9', 'V, S, M, F/DF', 'spellsC.html#crushing-hand', 'Large hand provides cover, pushes, or crushes your foes.'),
new Array('Cure Critical Wounds', 'Conjuration', 'Healing', '', 'Brd 4, Clr 4, Drd 5, Healing 4', 'V, S', 'spellsC.html#cure-critical-wounds', 'Cures 4d8 damage +1/level (max +20).'),
new Array('Cure Critical Wounds, Mass', 'Conjuration', 'Healing', '', 'Clr 8, Drd 9, Healing 8', 'V, S', 'spellsC.html#mass-cure-critical-wounds', 'Cures 4d8 damage +1/level for many creatures.'),
new Array('Cure Light Wounds', 'Conjuration', 'Healing', '', 'Brd 1, Clr 1, Drd 1, Healing 1, Pal 1, Rgr 2', 'V, S', 'spellsC.html#cure-light-wounds', 'Cures 1d8 damage +1/level (max +5).'),
new Array('Cure Light Wounds, Mass', 'Conjuration', 'Healing', '', 'Brd 5, Clr 5, Drd 6, Healing 5', 'V, S', 'spellsC.html#mass-cure-light-wounds', 'Cures 1d8 damage +1/level for many creatures.'),
new Array('Cure Minor Wounds', 'Conjuration', 'Healing', '', 'Clr 0, Drd 0', 'V, S', 'spellsC.html#cure-minor-wounds', 'Cures 1 point of damage.'),
new Array('Cure Moderate Wounds', 'Conjuration', 'Healing', '', 'Brd 2, Clr 2, Drd 3, Healing 2, Pal 3, Rgr 3', 'V, S', 'spellsC.html#cure-moderate-wounds', 'Cures 2d8 damage +1/level (max +10).'),
new Array('Cure Moderate Wounds, Mass', 'Conjuration', 'Healing', '', 'Brd 6, Clr 6, Drd 7', 'V, S', 'spellsC.html#mass-cure-moderate-wounds', 'Cures 2d8 damage +1/level for many creatures.'),
new Array('Cure Serious Wounds', 'Conjuration', 'Healing', '', 'Brd 3, Clr 3, Drd 4, Pal 4, Rgr 4, Healing 3', 'V, S', 'spellsC.html#cure-serious-wounds', 'Cures 3d8 damage +1/level (max +15).'),
new Array('Cure Serious Wounds, Mass', 'Conjuration', 'Healing', '', 'Clr 7, Drd 8', 'V, S', 'spellsC.html#mass-cure-serious-wounds', 'Cures 3d8 damage +1/level for many creatures.'),
new Array('Curse Water', 'Necromancy', '', 'Evil', 'Clr 1', 'V, S, M', 'spellsC.html#curse-water', 'Makes unholy water.'),
new Array('Dancing Lights', 'Evocation', '', 'Light', 'Brd 0, Sor/Wiz 0', 'V, S', 'spellsDtoE.html#dancing-lights', 'Creates torches or other lights.'),
new Array('Darkness', 'Evocation', '', 'Darkness', 'Brd 2, Clr 2, Sor/Wiz 2', 'V, M/DF', 'spellsDtoE.html#darkness', '20-ft. radius of supernatural shadow.'),
new Array('Darkvision', 'Transmutation', '', '', 'Rgr 3, Sor/Wiz 2', 'V, S, M', 'spellsDtoE.html#darkvision', 'See 60 ft. in total darkness.'),
new Array('Daylight', 'Evocation', '', 'Light', 'Brd 3, Clr 3, Drd 3, Pal 3, Sor/Wiz 3', 'V, S', 'spellsDtoE.html#daylight', '60-ft. radius of bright light.'),
new Array('Daze', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 0, Sor/Wiz 0', 'V, S, M', 'spellsDtoE.html#daze', 'Humanoid creature of 4 HD or less loses next action.'),
new Array('Daze Monster', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 2, Sor/Wiz 2', 'V, S, M', 'spellsDtoE.html#daze-monster', 'Living creature of 6 HD or less loses next action.'),
new Array('Death Knell', 'Necromancy', '', 'Death, Evil', 'Clr 2, Death 2', 'V, S', 'spellsDtoE.html#death-knell', 'Kills <a href="#" onClick="openLink(\'abilitiesAndConditions.html#dying\');return false" style="color: rgb(87, 158, 182);">dying</a> creature; you gain 1d8 temporary hp, +2 to Str, and +1 level.'),
new Array('Death Ward', 'Necromancy', '', '', 'Clr 4, Death 4, Drd 5, Pal 4', 'V, S, DF', 'spellsDtoE.html#death-ward', 'Grants immunity to death spells and negative energy effects.'),
new Array('Deathwatch', 'Necromancy', '', 'Evil', 'Clr 1', 'V, S', 'spellsDtoE.html#deathwatch', 'Reveals how near death subjects within 30 ft. are.'),
new Array('Deep Slumber', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 3, Sor/Wiz 3', 'V, S, M', 'spellsDtoE.html#deep-slumber', 'Puts 10 HD of creatures to sleep.'),
new Array('Deeper Darkness', 'Evocation', '', 'Darkness', 'Clr 3', 'V, M/DF', 'spellsDtoE.html#deeper-darkness', 'Object sheds supernatural shadow in 60-ft. radius.'),
new Array('Delay Poison', 'Conjuration', 'Healing', '', 'Brd 2, Clr 2, Drd 2, Pal 2, Rgr 1', 'V, S, DF', 'spellsDtoE.html#delay-poison', 'Stops poison from harming subject for 1 hour/level.'),
new Array('Delayed Blast Fireball', 'Evocation', '', 'Fire', 'Sor/Wiz 7', 'V, S, M', 'spellsDtoE.html#delayed-blast-fireball', '1d6/level fire damage; you can postpone blast for 5 rounds.'),
new Array('Demand', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Sor/Wiz 8', 'V, S, M/DF', 'spellsDtoE.html#demand', 'As sending, plus you can send suggestion.'),
new Array('Desecrate', 'Evocation', '', 'Evil', 'Clr 2, Evil 2', 'V, S, M, DF', 'spellsDtoE.html#desecrate', 'Fills area with negative energy, making undead stronger.'),
new Array('Destruction', 'Necromancy', '', 'Death', 'Clr 7, Death 7', 'V, S, F', 'spellsDtoE.html#destruction', 'Kills subject and destroys remains.'),
new Array('Detect Animals or Plants', 'Divination', '', '', 'Drd 1, Rgr 1', 'V, S', 'spellsDtoE.html#detect-animals-or-plants', 'Detects kinds of animals or plants.'),
new Array('Detect Chaos', 'Divination', '', '', 'Clr 1', 'V, S, DF', 'spellsDtoE.html#detect-chaos', 'Reveals creatures, spells, or objects of selected alignment.'),
new Array('Detect Evil', 'Divination', '', '', 'Clr 1', 'V, S, DF', 'spellsDtoE.html#detect-evil', 'Reveals creatures, spells, or objects of selected alignment.'),
new Array('Detect Good', 'Divination', '', '', 'Clr 1', 'V, S, DF', 'spellsDtoE.html#detect-good', 'Reveals creatures, spells, or objects of selected alignment.'),
new Array('Detect Law', 'Divination', '', '', 'Clr 1', 'V, S, DF', 'spellsDtoE.html#detect-law', 'Reveals creatures, spells, or objects of selected alignment.'),
new Array('Detect Magic', 'Divination', '', '', 'Brd 0, Clr 0, Drd 0, Sor/Wiz 0', 'V, S', 'spellsDtoE.html#detect-magic', 'Detects spells and magic items within 60 ft.'),
new Array('Detect Poison', 'Divination', '', '', 'Clr 0, Drd 0, Pal 1, Rgr 1, Sor/Wiz 0', 'V, S', 'spellsDtoE.html#detect-poison', 'Detects poison in one creature or small object.'),
new Array('Detect Scrying', 'Divination', '', '', 'Brd 4, Sor/Wiz 4', 'V, S, M', 'spellsDtoE.html#detect-scrying', 'Alerts you of magical eavesdropping.'),
new Array('Detect Secret Doors', 'Divination', '', '', 'Brd 1, Knowledge 1, Sor/Wiz 1', 'V, S', 'spellsDtoE.html#detect-secret-doors', 'Reveals hidden doors within 60 ft.'),
new Array('Detect Snares and Pits', 'Divination', '', '', 'Drd 1, Rgr 1', 'V, S', 'spellsDtoE.html#detect-snares-and-pits', 'Reveals natural or primitive traps.'),
new Array('Detect Thoughts', 'Divination', '', 'Mind-Affecting', 'Brd 2, Knowledge 2, Sor/Wiz 2', 'V, S, F/DF', 'spellsDtoE.html#detect-thoughts', 'Allows &#8220;listening&#8221; to surface thoughts.'),
new Array('Detect Undead', 'Divination', '', '', 'Clr 1, Pal 1, Sor/Wiz 1', 'V, S, M/DF', 'spellsDtoE.html#detect-undead', 'Reveals undead within 60 ft.'),
new Array('Dictum', 'Evocation', '', 'Lawful, Sonic', 'Clr 7, Law 7', 'V', 'spellsDtoE.html#dictum', 'Kills, paralyzes, slows, or deafens nonlawful subjects.'),
new Array('Dimension Door', 'Conjuration', 'Teleportation', '', 'Brd 4, Sor/Wiz 4, Travel 4', 'V', 'spellsDtoE.html#dimension-door', 'Teleports you short distance.'),
new Array('Dimensional Anchor', 'Abjuration', '', '', 'Clr 4, Sor/Wiz 4', 'V, S', 'spellsDtoE.html#dimensional-anchor', 'Bars extradimensional movement.'),
new Array('Dimensional Lock', 'Abjuration', '', '', 'Clr 8, Sor/Wiz 8', 'V, S', 'spellsDtoE.html#dimensional-lock', 'Teleportation and interplanar travel blocked for one day/level.'),
new Array('Diminish Plants', 'Transmutation', '', '', 'Drd 3, Rgr 3', 'V, S, DF', 'spellsDtoE.html#diminish-plants', 'Reduces size or blights growth of normal plants.'),
new Array('Discern Lies', 'Divination', '', '', 'Clr 4, Pal 3', 'V, S, DF', 'spellsDtoE.html#discern-lies', 'Reveals deliberate falsehoods.'),
new Array('Discern Location', 'Divination', '', '', 'Clr 8, Knowledge 8, Sor/Wiz 8', 'V, S, DF', 'spellsDtoE.html#discern-location', 'Reveals exact location of creature or object.'),
new Array('Disguise Self', 'Illusion', 'Glamer', '', 'Brd 1, Sor/Wiz 1, Trickery 1', 'V, S', 'spellsDtoE.html#disguise-self', 'Changes your appearance.'),
new Array('Disintegrate', 'Transmutation', '', '', 'Destruction 7, Sor/Wiz 6', 'V, S, M/DF', 'spellsDtoE.html#disintegrate', 'Makes one creature or object vanish.'),
new Array('Dismissal', 'Abjuration', '', '', 'Clr 4, Sor/Wiz 5', 'V, S, DF', 'spellsDtoE.html#dismissal', 'Forces a creature to return to native plane.'),
new Array('Dispel Chaos', 'Abjuration', '', 'Lawful', 'Clr 5, Law 5, Pal 4', 'V, S, DF', 'spellsDtoE.html#dispel-chaos', '+4 bonus against attacks.'),
new Array('Dispel Evil', 'Abjuration', '', 'Good', 'Clr 5, Good 5, Pal 4', 'V, S, DF', 'spellsDtoE.html#dispel-evil', '+4 bonus against attacks by evil creatures.'),
new Array('Dispel Good', 'Abjuration', '', 'Evil', 'Clr 5, Evil 5', 'V, S, DF', 'spellsDtoE.html#dispel-good', '+4 bonus against attacks by good creatures.'),
new Array('Dispel Law', 'Abjuration', '', 'Chaotic', 'Chaos 5, Clr 5', 'V, S, DF', 'spellsDtoE.html#dispel-law', '+4 bonus against attacks by lawful creatures.'),
new Array('Dispel Magic', 'Abjuration', '', '', 'Brd 3, Clr 3, Drd 4, Magic 3, Pal 3, Sor/Wiz 3', 'V, S', 'spellsDtoE.html#dispel-magic', 'Cancels magical spells and effects.'),
new Array('Dispel Magic, Greater', 'Abjuration', '', '', 'Brd 5, Clr 6, Drd 6, Sor/Wiz 6', 'V, S', 'spellsDtoE.html#greater-dispel-magic', 'As dispel magic, but +20 on check.'),
new Array('Displacement', 'Illusion', 'Glamer', '', 'Brd 3, Sor/Wiz 3', 'V, M', 'spellsDtoE.html#displacement', 'Attacks miss subject 50%.'),
new Array('Disrupt Undead', 'Necromancy', '', '', 'Sor/Wiz 0', 'V, S', 'spellsDtoE.html#disrupt-undead', 'Deals 1d6 damage to one undead.'),
new Array('Disrupting Weapon', 'Transmutation', '', '', 'Clr 5', 'V, S', 'spellsDtoE.html#disrupting-weapon', 'Melee weapon destroys undead.'),
new Array('Divination', 'Divination', '', '', 'Clr 4, Knowledge 4', 'V, S, M', 'spellsDtoE.html#divination', 'Provides useful advice for specific proposed actions.'),
new Array('Divine Favor', 'Evocation', '', '', 'Clr 1, Pal 1', 'V, S, DF', 'spellsDtoE.html#divine-favor', 'You gain +1 per three levels on attack and damage rolls.'),
new Array('Divine Power', 'Evocation', '', '', 'Clr 4, War 4', 'V, S, DF', 'spellsDtoE.html#divine-power', 'You gain attack bonus, +6 to Str, and 1 hp/level.'),
new Array('Dominate Animal', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Animal 3, Drd 3', 'V, S', 'spellsDtoE.html#dominate-animal', 'Subject animal obeys silent mental commands.'),
new Array('Dominate Monster', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Sor/Wiz 9', 'V, S', 'spellsDtoE.html#dominate-monster', 'As dominate person, but any creature.'),
new Array('Dominate Person', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 4, Sor/Wiz 5', 'V, S', 'spellsDtoE.html#dominate-person', 'Controls humanoid telepathically.'),
new Array('Doom', 'Necromancy', '', 'Fear, Mind-Affecting', 'Clr 1', 'V, S, DF', 'spellsDtoE.html#doom', 'One subject takes &#8211;2 on attack rolls, damage rolls, saves, and checks.'),
new Array('Dream', 'Illusion', 'Phantasm', 'Mind-Affecting', 'Brd 5, Sor/Wiz 5', 'V, S', 'spellsDtoE.html#dream', 'Sends message to anyone sleeping.'),
new Array('Eagle\'s Splendor', 'Transmutation', '', '', 'Brd 2, Clr 2, Pal 2, Sor/Wiz 2', 'V, S, M/DF', 'spellsDtoE.html#eagles-splendor', 'Subject gains +4 to Cha for 1 min./level.'),
new Array('Eagle\'s Splendor, Mass', 'Transmutation', '', '', 'Brd 6, Clr 6, Sor/Wiz 6', 'V, S, M/DF', 'spellsDtoE.html#mass-eagles-splendor', 'As eagle&#8217;s splendor, affects one subject/level.'),
new Array('Earthquake', 'Evocation', '', 'Earth', 'Clr 8, Destruction 8, Drd 8, Earth 7', 'V, S, DF', 'spellsDtoE.html#earthquake', 'Intense tremor shakes 5-ft./level radius.'),
new Array('Elemental Swarm', 'Conjuration', 'Summoning', 'see text', 'Air 9, Drd 9, Earth 9, Fire 9, Water 9', 'V, S', 'spellsDtoE.html#elemental-swarm', 'Summons multiple elementals.'),
new Array('Endure Elements', 'Abjuration', '', '', 'Clr 1, Drd 1, Pal 1, Rgr 1, Sor/Wiz 1, Sun 1', 'V, S', 'spellsDtoE.html#endure-elements', 'Exist comfortably in hot or cold environments.'),
new Array('Energy Drain', 'Necromancy', '', '', 'Clr 9, Sor/Wiz 9', 'V, S', 'spellsDtoE.html#energy-drain', 'Subject gains 2d4 negative levels.'),
new Array('Enervation', 'Necromancy', '', '', 'Sor/Wiz 4', 'V, S', 'spellsDtoE.html#enervation', 'Subject gains 1d4 negative levels.'),
new Array('Enlarge Person', 'Transmutation', '', '', 'Sor/Wiz 1, Strength 1', 'V, S, M', 'spellsDtoE.html#enlarge-person', 'Humanoid creature doubles in size.'),
new Array('Enlarge Person, Mass', 'Transmutation', '', '', 'Sor/Wiz 4', 'V, S, M', 'spellsDtoE.html#mass-enlarge-person', 'Enlarges several creatures.'),
new Array('Entangle', 'Transmutation', '', '', 'Drd 1, Plant 1, Rgr 1', 'V, S, DF', 'spellsDtoE.html#entangle', 'Plants entangle everyone in 40-ft.-radius.'),
new Array('Enthrall', 'Enchantment', 'Charm', 'Language-Dependent, Mind-Affecting, Sonic', 'Brd 2, Clr 2', 'V, S', 'spellsDtoE.html#enthrall', 'Captivates all within 100 ft. + 10 ft./level.'),
new Array('Entropic Shield', 'Abjuration', '', '', 'Clr 1, Luck 1', 'V, S', 'spellsDtoE.html#entropic-shield', 'Ranged attacks against you have 20% miss chance.'),
new Array('Erase', 'Transmutation', '', '', 'Brd 1, Sor/Wiz 1', 'V, S', 'spellsDtoE.html#erase', 'Mundane or magical writing vanishes.'),
new Array('Ethereal Jaunt', 'Transmutation', '', '', 'Clr 7, Sor/Wiz 7', 'V, S', 'spellsDtoE.html#ethereal-jaunt', 'You become ethereal for 1 round/level.'),
new Array('Etherealness', 'Transmutation', '', '', 'Clr 9, Sor/Wiz 9', 'V, S', 'spellsDtoE.html#etherealness', 'Travel to Ethereal Plane with companions.'),
new Array('Expeditious Retreat', 'Transmutation', '', '', 'Brd 1, Sor/Wiz 1', 'V, S', 'spellsDtoE.html#expeditious-retreat', 'Your speed increases by 30 ft.'),
new Array('Explosive Runes', 'Abjuration', '', 'Force', 'Sor/Wiz 3', 'V, S', 'spellsDtoE.html#explosive-runes', 'Deals 6d6 damage when read.'),
new Array('Eyebite', 'Necromancy', '', 'Evil', 'Brd 6, Sor/Wiz 6', 'V, S', 'spellsDtoE.html#eyebite', 'Target becomes <a href="#" onClick="openLink(\'abilitiesAndConditions.html#panicked\');return false" style="color: rgb(87, 158, 182);">panicked</a>, <a href="#" onClick="openLink(\'abilitiesAndConditions.html#sickened\');return false" style="color: rgb(87, 158, 182);">sickened</a>, and comatose.'),
new Array('Fabricate', 'Transmutation', '', '', 'Sor/Wiz 5', 'V, S, M', 'spellsFtoG.html#fabricate', 'Transforms raw materials into finished items.'),
new Array('Faerie Fire', 'Evocation', '', 'Light', 'Drd 1', 'V, S, DF', 'spellsFtoG.html#faerie-fire', 'Outlines subjects with light, canceling blur, concealment, and the like.'),
new Array('False Life', 'Necromancy', '', '', 'Sor/Wiz 2', 'V, S, M', 'spellsFtoG.html#false-life', 'Gain 1d10 temporary hp +1/level (max +10).'),
new Array('False Vision', 'Illusion', 'Glamer', '', 'Brd 5, Sor/Wiz 5, Trickery 5', 'V, S, M', 'spellsFtoG.html#false-vision', 'Fools scrying with an illusion.'),
new Array('Fear', 'Necromancy', '', 'Fear, Mind-Affecting', 'Brd 3, Sor/Wiz 4', 'V, S, M', 'spellsFtoG.html#fear', 'Subjects within cone flee for 1 round/level.'),
new Array('Feather Fall', 'Transmutation', '', '', 'Brd 1, Sor/Wiz 1', 'V', 'spellsFtoG.html#feather-fall', 'Objects or creatures fall slowly.'),
new Array('Feeblemind', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Sor/Wiz 5', 'V, S, M', 'spellsFtoG.html#feeblemind', 'Subject&#8217;s Int and Cha drop to 1.'),
new Array('Find Traps', 'Divination', '', '', 'Clr 2', 'V, S', 'spellsFtoG.html#find-traps', 'Notice traps as a rogue does.'),
new Array('Find the Path', 'Divination', '', '', 'Brd 6, Clr 6, Drd 6, Knowledge 6, Travel 6', 'V, S, F', 'spellsFtoG.html#find-the-path', 'Shows most direct way to a location.'),
new Array('Finger of Death', 'Necromancy', '', 'Death', 'Drd 8, Sor/Wiz 7', 'V, S', 'spellsFtoG.html#finger-of-death', 'Kills one subject.'),
new Array('Fire Seeds', 'Conjuration', 'Creation', 'Fire', 'Drd 6, Fire 6, Sun 6', 'V, S, M', 'spellsFtoG.html#fire-seeds', 'Acorns and berries become grenades and bombs.'),
new Array('Fire Shield', 'Evocation', '', 'Fire or Cold', 'Fire 5, Sor/Wiz 4, Sun 4', 'V, S, M/DF', 'spellsFtoG.html#fire-shield', 'Creatures attacking you take fire damage; you&#8217;re protected from heat or cold.'),
new Array('Fire Storm', 'Evocation', '', 'Fire', 'Clr 8, Drd 7, Fire 7', 'V, S', 'spellsFtoG.html#fire-storm', 'Deals 1d6/level fire damage.'),
new Array('Fire Trap', 'Abjuration', '', 'Fire', 'Drd 2, Sor/Wiz 4', 'V, S, M', 'spellsFtoG.html#fire-trap', 'Opened object deals 1d4 damage +1/level.'),
new Array('Fireball', 'Evocation', '', 'Fire', 'Sor/Wiz 3', 'V, S, M', 'spellsFtoG.html#fireball', '1d6 damage per level, 20-ft. radius.'),
new Array('Flame Arrow', 'Transmutation', '', 'Fire', 'Sor/Wiz 3', 'V, S, M', 'spellsFtoG.html#flame-arrow', 'Arrows deal +1d6 fire damage.'),
new Array('Flame Blade', 'Evocation', '', 'Fire', 'Drd 2', 'V, S, DF', 'spellsFtoG.html#flame-blade', 'Touch attack deals 1d8 +1/two levels damage.'),
new Array('Flame Strike', 'Evocation', '', 'Fire', 'Clr 5, Drd 4, Sun 5, War 5', 'V, S, DF', 'spellsFtoG.html#flame-strike', 'Smite foes with divine fire (1d6/level damage).'),
new Array('Flaming Sphere', 'Evocation', '', 'Fire', 'Drd 2, Sor/Wiz 2', 'V, S, M/DF', 'spellsFtoG.html#flaming-sphere', 'Creates rolling ball of fire, 2d6 damage, lasts 1 round/level.'),
new Array('Flare', 'Evocation', '', 'Light', 'Brd 0, Drd 0, Sor/Wiz 0', 'V', 'spellsFtoG.html#flare', 'Dazzles one creature (&#8211;1 on attack rolls).'),
new Array('Flesh to Stone', 'Transmutation', '', '', 'Sor/Wiz 6', 'V, S, M', 'spellsFtoG.html#flesh-to-stone', 'Turns subject creature into statue.'),
new Array('Floating Disk', 'Evocation', '', 'Force', 'Sor/Wiz 1', 'V, S, M', 'spellsFtoG.html#floating-disk', 'Creates 3-ft.-diameter horizontal disk that holds 100 lb./level.'),
new Array('Fly', 'Transmutation', '', '', 'Sor/Wiz 3, Travel 3', 'V, S, F/DF', 'spellsFtoG.html#fly', 'Subject flies at speed of 60 ft.'),
new Array('Fog Cloud', 'Conjuration', 'Creation', '', 'Drd 2, Sor/Wiz 2, Water 2', 'V, S', 'spellsFtoG.html#fog-cloud', 'Fog obscures vision.'),
new Array('Forbiddance', 'Abjuration', '', '', 'Clr 6', 'V, S, M, DF', 'spellsFtoG.html#forbiddance', 'Blocks planar travel, damages creatures of different alignment.'),
new Array('Forcecage', 'Evocation', '', 'Force', 'Sor/Wiz 7', 'V, S, M', 'spellsFtoG.html#forcecage', 'Cube or cage of force imprisons all inside.'),
new Array('Forceful Hand', 'Evocation', '', 'Force', 'Sor/Wiz 6', 'V, S, F', 'spellsFtoG.html#forceful-hand', 'Hand pushes creatures away.'),
new Array('Foresight', 'Divination', '', '', 'Drd 9, Knowledge 9, Sor/Wiz 9', 'V, S, M/DF', 'spellsFtoG.html#foresight', '&#8220;Sixth sense&#8221; warns of impending danger.'),
new Array('Fox\'s Cunning', 'Transmutation', '', '', 'Brd 2, Sor/Wiz 2', 'V, S, M/DF', 'spellsFtoG.html#foxs-cunning', 'Subject gains +4 Int for 1 min./level.'),
new Array('Fox\'s Cunning, Mass', 'Transmutation', '', '', 'Brd 6, Sor/Wiz 6', 'V, S, M/DF', 'spellsFtoG.html#mass-foxs-cunning', 'As fox&#8217;s cunning, affects one subject/ level.'),
new Array('Freedom', 'Abjuration', '', '', 'Sor/Wiz 9', 'V, S', 'spellsFtoG.html#freedom', 'Releases creature from imprisonment.'),
new Array('Freedom of Movement', 'Abjuration', '', '', 'Brd 4, Clr 4, Drd 4, Luck 4, Rgr 4', 'V, S, M, DF', 'spellsFtoG.html#freedom-of-movement', 'Subject moves normally despite impediments.'),
new Array('Freezing Sphere', 'Evocation', '', 'Cold', 'Sor/Wiz 6', 'V, S, F', 'spellsFtoG.html#freezing-sphere', 'Freezes water or deals cold damage.'),
new Array('Gaseous Form', 'Transmutation', '', '', 'Air 3, Brd 3, Sor/Wiz 3', 'S, M/DF', 'spellsFtoG.html#gaseous-form', 'Subject becomes insubstantial and can fly slowly.'),
new Array('Gate', 'Conjuration', 'Creation or Calling', '', 'Clr 9, Sor/Wiz 9', 'V, S, XP; see text', 'spellsFtoG.html#gate', 'Connects two planes for travel or summoning.'),
new Array('Geas, Lesser', 'Enchantment', 'Compulsion', 'Language-Dependent, Mind-Affecting', 'Brd 3, Sor/Wiz 4', 'V', 'spellsFtoG.html#lesser-geas', 'Commands subject of 7 HD or less.'),
new Array('Geas/Quest', 'Enchantment', 'Compulsion', 'Language-Dependent, Mind-Affecting', 'Brd 6, Clr 6, Sor/Wiz 6', 'V', 'spellsFtoG.html#geas/quest', 'As lesser geas, plus it affects any creature.'),
new Array('Gentle Repose', 'Necromancy', '', '', 'Clr 2, Sor/Wiz 3', 'V, S, M/DF', 'spellsFtoG.html#gentle-repose', 'Preserves one corpse.'),
new Array('Ghost Sound', 'Illusion', 'Figment', '', 'Brd 0, Sor/Wiz 0', 'V, S, M', 'spellsFtoG.html#ghost-sound', 'Figment sounds.'),
new Array('Ghoul Touch', 'Necromancy', '', '', 'Sor/Wiz 2', 'V, S, M', 'spellsFtoG.html#ghoul-touch', 'Paralyzes one subject, which exudes stench that makes those nearby <a href="#" onClick="openLink(\'abilitiesAndConditions.html#sickened\');return false" style="color: rgb(87, 158, 182);">sickened</a>.'),
new Array('Giant Vermin', 'Transmutation', '', '', 'Clr 4, Drd 4', 'V, S, DF', 'spellsFtoG.html#giant-vermin', 'Turns centipedes, scorpions, or spiders into giant vermin.'),
new Array('Glibness', 'Transmutation', '', '', 'Brd 3', 'S', 'spellsFtoG.html#glibness', 'You gain +30 bonus on <a href="#" onClick="openLink(\'skillsAll.html#bluff\');return false" style="color: rgb(87, 158, 182);">Bluff</a> checks, and your lies can escape magical discernment.'),
new Array('Glitterdust', 'Conjuration', 'Creation', '', 'Brd 2, Sor/Wiz 2', 'V, S, M', 'spellsFtoG.html#glitterdust', '<a href="#" onClick="openLink(\'abilitiesAndConditions.html#blinded\');return false" style="color: rgb(87, 158, 182);">Blinds</a> creatures, outlines <a href="#" onClick="openLink(\'abilitiesAndConditions.html#invisible\');return false" style="color: rgb(87, 158, 182);">invisible</a> creatures.'),
new Array('Globe of Invulnerability', 'Abjuration', '', '', 'Sor/Wiz 6', 'V, S, M', 'spellsFtoG.html#globe-of-invulnerability', 'As lesser globe of invulnerability, plus 4th-level spell effects.'),
new Array('Globe of Invulnerability, Lesser', 'Abjuration', '', '', 'Sor/Wiz 4', 'V, S, M', 'spellsFtoG.html#lesser-globe-of-invulnerability', 'Stops 1st- through 3rd-level spell effects.'),
new Array('Glyph of Warding', 'Abjuration', '', '', 'Clr 3', 'V, S, M', 'spellsFtoG.html#glyph-of-warding', 'Inscription harms those who pass it.'),
new Array('Glyph of Warding, Greater', 'Abjuration', '', '', 'Clr 6', 'V, S, M', 'spellsFtoG.html#greater-glyph-of-warding', 'As glyph of warding, but up to 10d8 damage or 6th-level spell.'),
new Array('Good Hope', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 3', 'V, S', 'spellsFtoG.html#good-hope', 'Subjects gain +2 on attack rolls, damage rolls, saves, and checks.'),
new Array('Goodberry', 'Transmutation', '', '', 'Drd 1', 'V, S, DF', 'spellsFtoG.html#goodberry', '2d4 berries each cure 1 hp (max 8 hp/24 hours).'),
new Array('Grasping Hand', 'Evocation', '', 'Force', 'Sor/Wiz 7, Strength 7', 'V, S, F/DF', 'spellsFtoG.html#grasping-hand', 'Hand provides cover, pushes, or <a href="#" onClick="openLink(\'specialAttacks.html#grapple\');return false" style="color: rgb(87, 158, 182);">grapples</a>.'),
new Array('Grease', 'Conjuration', 'Creation', '', 'Brd 1, Sor/Wiz 1', 'V, S, M', 'spellsFtoG.html#grease', 'Makes 10-ft. square or one object slippery.'),
new Array('Guards and Wards', 'Abjuration', '', '', 'Sor/Wiz 6', 'V, S, M, F', 'spellsFtoG.html#guards-and-wards', 'Array of magic effects protect area.'),
new Array('Guidance', 'Divination', '', '', 'Clr 0, Drd 0', 'V, S', 'spellsFtoG.html#guidance', '+1 on one attack roll, saving throw, or skill check.'),
new Array('Gust of Wind', 'Evocation', '', 'Air', 'Drd 2, Sor/Wiz 2', 'V, S', 'spellsFtoG.html#gust-of-wind', 'Blows away or knocks down smaller creatures.'),
new Array('Hallow', 'Evocation', '', 'Good', 'Clr 5, Drd 5', 'V, S, M, DF', 'spellsHtoL.html#hallow', 'Designates location as holy.'),
new Array('Hallucinatory Terrain', 'Illusion', 'Glamer', '', 'Brd 4, Sor/Wiz 4', 'V, S, M', 'spellsHtoL.html#hallucinatory-terrain', 'Makes one type of terrain appear like another (field into forest, or the like).'),
new Array('Halt Undead', 'Necromancy', '', '', 'Sor/Wiz 3', 'V, S, M', 'spellsHtoL.html#halt-undead', 'Immobilizes undead for 1 round/level.'),
new Array('Harm', 'Necromancy', '', '', 'Clr 6, Destruction 6', 'V, S', 'spellsHtoL.html#harm', 'Deals 10 points/level damage to target.'),
new Array('Haste', 'Transmutation', '', '', 'Brd 3, Sor/Wiz 3', 'V, S, M', 'spellsHtoL.html#haste', 'One creature/level moves faster, +1 on attack rolls, AC, and Reflex saves.'),
new Array('Heal', 'Conjuration', 'Healing', '', 'Clr 6, Drd 7, Healing 6', 'V, S', 'spellsHtoL.html#heal', 'Cures 10 points/level of damage, all diseases and mental conditions.'),
new Array('Heal Mount', 'Conjuration', 'Healing', '', 'Pal 3', 'V, S', 'spellsHtoL.html#heal-mount', 'As heal on warhorse or other special mount.'),
new Array('Heal, Mass', 'Conjuration', 'Healing', '', 'Clr 9, Healing 9', 'V, S', 'spellsHtoL.html#mass-heal', 'As heal, but with several subjects.'),
new Array('Heat Metal', 'Transmutation', '', 'Fire', 'Drd 2, Sun 2', 'V, S, DF', 'spellsHtoL.html#heat-metal', 'Make metal so hot it damages those who touch it.'),
new Array('Helping Hand', 'Evocation', '', '', 'Clr 3', 'V, S, DF', 'spellsHtoL.html#helping-hand', 'Ghostly hand leads subject to you.'),
new Array('Heroes\' Feast', 'Conjuration', '', 'Creation', 'Brd 6, Clr 6', 'V, S, DF', 'spellsHtoL.html#heroes-feast', 'Food for one creature/level cures and grants combat bonuses.'),
new Array('Heroism', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 2, Sor/Wiz 3', 'V, S', 'spellsHtoL.html#heroism', 'Gives +2 bonus on attack rolls, saves, skill checks.'),
new Array('Heroism, Greater', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 5, Sor/Wiz 6', 'V, S', 'spellsHtoL.html#greater-heroism', 'Gives +4 bonus on attack rolls, saves, skill checks; immunity to fear; temporary hp.'),
new Array('Hide from Animals', 'Abjuration', '', '', 'Drd 1, Rgr 1', 'S, DF', 'spellsHtoL.html#hide-from-animals', 'Animals can&#8217;t perceive one subject/level.'),
new Array('Hide from Undead', 'Abjuration', '', '', 'Clr 1', 'V, S, DF', 'spellsHtoL.html#hide-from-undead', 'Undead can&#8217;t perceive one subject/level.'),
new Array('Hideous Laughter', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 1, Sor/Wiz 2', 'V, S, M', 'spellsHtoL.html#hideous-laughter', 'Subject loses actions for 1 round/level.'),
new Array('Hold Animal', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Animal 2, Drd 2, Rgr 2', 'V, S', 'spellsHtoL.html#hold-animal', 'Paralyzes one animal for 1 round/level.'),
new Array('Hold Monster', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 4, Law 6, Sor/Wiz 5', 'V, S, M/DF', 'spellsHtoL.html#hold-monster', 'As hold person, but any creature.'),
new Array('Hold Monster, Mass', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Sor/Wiz 9', 'V, S, M/DF', 'spellsHtoL.html#mass-hold-monster', 'As hold monster, but all within 30 ft.'),
new Array('Hold Person', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 2, Clr 2, Sor/Wiz 3', 'V, S, F/DF', 'spellsHtoL.html#hold-person', 'Paralyzes one humanoid for 1 round/level.'),
new Array('Hold Person, Mass', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Sor/Wiz 7', 'V, S, F/D', 'spellsHtoL.html#mass-hold-person', 'As hold person, but all within 30 ft.'),
new Array('Hold Portal', 'Abjuration', '', '', 'Sor/Wiz 1', 'V', 'spellsHtoL.html#hold-portal', 'Holds door shut.'),
new Array('Holy Aura', 'Abjuration', '', 'Good', 'Clr 8, Good 8', 'V, S, F', 'spellsHtoL.html#holy-aura', '+4 to AC, +4 resistance, and SR 25 against evil spells.'),
new Array('Holy Smite', 'Evocation', '', 'Good', 'Good 4', 'V, S', 'spellsHtoL.html#holy-smite', 'Damages and <a href="#" onClick="openLink(\'abilitiesAndConditions.html#blinded\');return false" style="color: rgb(87, 158, 182);">blinds</a> evil creatures.'),
new Array('Holy Sword', 'Evocation', '', 'Good', 'Pal 4', 'V, S', 'spellsHtoL.html#holy-sword', 'Weapon becomes +5, deals +2d6 damage against evil.'),
new Array('Holy Word', 'Evocation', '', 'Good, Sonic', 'Clr 7, Good 7', 'V', 'spellsHtoL.html#holy-word', 'Kills, paralyzes, <a href="#" onClick="openLink(\'abilitiesAndConditions.html#blinded\');return false" style="color: rgb(87, 158, 182);">blinds</a>, or <a href="#" onClick="openLink(\'abilitiesAndConditions.html#deafened\');return false" style="color: rgb(87, 158, 182);">deafens</a> nongood subjects.'),
new Array('Horrid Wilting', 'Necromancy', '', '', 'Sor/Wiz 8, Water 8', 'V, S, M/DF', 'spellsHtoL.html#horrid-wilting', 'Deals 1d6/level damage within 30 ft.'),
new Array('Hypnotic Pattern', 'Illusion', 'Pattern', 'Mind-Affecting', 'Brd 2, Sor/Wiz 2', 'V (Brd only), S, M; see text', 'spellsHtoL.html#hypnotic-pattern', 'Fascinates (2d4 + level) HD of creatures.'),
new Array('Hypnotism', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 1, Sor/Wiz 1', 'V, S', 'spellsHtoL.html#hypnotism', 'Fascinates 2d4 HD of creatures.'),
new Array('Ice Storm', 'Evocation', '', 'Cold', 'Drd 4, Sor/Wiz 4, Water 5', 'V, S, M/DF', 'spellsHtoL.html#ice-storm', 'Hail deals 5d6 damage in cylinder 40 ft. across.'),
new Array('Identify', 'Divination', '', '', 'Brd 1, Magic 2, Sor/Wiz 1', 'V, S, M/DF', 'spellsHtoL.html#identify', 'Determines properties of magic item.'),
new Array('Illusory Script', 'Illusion', 'Phantasm', 'Mind-Affecting', 'Brd 3, Sor/Wiz 3', 'V, S, M', 'spellsHtoL.html#illusory-script', 'Only intended reader can decipher.'),
new Array('Illusory Wall', 'Illusion', 'Figment', '', 'Sor/Wiz 4', 'V, S', 'spellsHtoL.html#illusory-wall', 'Wall, floor, or ceiling looks real, but anything can pass through.'),
new Array('Imbue with Spell Ability', 'Evocation', '', '', 'Clr 4, Magic 4', 'V, S, DF', 'spellsHtoL.html#imbue-with-spell-ability', 'Transfer spells to subject.'),
new Array('Implosion', 'Evocation', '', '', 'Clr 9, Destruction 9', 'V, S', 'spellsHtoL.html#implosion', 'Kills one creature/round.'),
new Array('Imprisonment', 'Abjuration', '', '', 'Sor/Wiz 9', 'V, S', 'spellsHtoL.html#imprisonment', 'Entombs subject beneath the earth.'),
new Array('Incendiary Cloud', 'Conjuration', 'Creation', 'Fire', 'Fire 8, Sor/Wiz 8', 'V, S', 'spellsHtoL.html#incendiary-cloud', 'Cloud deals 4d6 fire damage/round.'),
new Array('Inflict Critical Wounds', 'Necromancy', '', '', 'Clr 4, Destruction 4', 'V, S', 'spellsHtoL.html#inflict-critical-wounds', 'Touch attack, 4d8 damage +1/level (max +20).'),
new Array('Inflict Critical Wounds, Mass', 'Necromancy', '', '', 'Clr 8', 'V, S', 'spellsHtoL.html#mass-inflict-critical-wounds', 'Deals 4d8 damage +1/level to many creatures.'),
new Array('Inflict Light Wounds', 'Necromancy', '', '', 'Clr 1, Destruction 1', 'V, S', 'spellsHtoL.html#inflict-light-wounds', 'Touch deals 1d8 damage +1/level (max +5).'),
new Array('Inflict Light Wounds, Mass', 'Necromancy', '', '', 'Clr 5, Destruction 5', 'V, S', 'spellsHtoL.html#mass-inflict-light-wounds', 'Deals 1d8 damage +1/level to many creatures.'),
new Array('Inflict Minor Wounds', 'Necromancy', '', '', 'Clr 0', 'V, S', 'spellsHtoL.html#inflict-minor-wounds', 'Touch attack, 1 point of damage.'),
new Array('Inflict Moderate Wounds', 'Necromancy', '', '', 'Clr 2', 'V, S', 'spellsHtoL.html#inflict-moderate-wounds', 'Touch attack, 2d8 damage +1/level (max +10).'),
new Array('Inflict Moderate Wounds, Mass', 'Necromancy', '', '', 'Clr 6', 'V, S', 'spellsHtoL.html#mass-inflict-moderate-wounds', 'Deals 2d8 damage +1/level to many creatures.'),
new Array('Inflict Serious Wounds', 'Necromancy', '', '', 'Clr 3', 'V, S', 'spellsHtoL.html#inflict-serious-wounds', 'Touch attack, 3d8 damage +1/level (max +15).'),
new Array('Inflict Serious Wounds, Mass', 'Necromancy', '', '', 'Clr 7', 'V, S', 'spellsHtoL.html#mass-inflict-serious-wounds', 'Deals 3d8 damage +1/level to many creatures.'),
new Array('Insanity', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Sor/Wiz 7', 'V, S', 'spellsHtoL.html#insanity', 'Subject suffers continuous confusion.'),
new Array('Insect Plague', 'Conjuration', 'Summoning', '', 'Clr 5, Drd 5', 'V, S, DF', 'spellsHtoL.html#insect-plague', 'Locust swarms attack creatures.'),
new Array('Instant Summons', 'Conjuration', 'Summoning', '', 'Sor/Wiz 7', 'V, S, M', 'spellsHtoL.html#instant-summons', 'Prepared object appears in your hand.'),
new Array('Interposing Hand', 'Evocation', '', 'Force', 'Sor/Wiz 5', 'V, S, F', 'spellsHtoL.html#interposing-hand', 'Hand provides cover against one opponent.'),
new Array('Invisibility', 'Illusion', 'Glamer', '', 'Brd 2, Sor/Wiz 2, Trickery 2', 'V, S, M/DF', 'spellsHtoL.html#invisibility', 'Subject is <a href="#" onClick="openLink(\'abilitiesAndConditions.html#invisible\');return false" style="color: rgb(87, 158, 182);">invisible</a> for 1 min./level or until it attacks.'),
new Array('Invisibility Purge', 'Evocation', '', '', 'Clr 3', 'V, S', 'spellsHtoL.html#invisibility-purge', 'Dispels invisibility within 5 ft./level.'),
new Array('Invisibility Sphere', 'Illusion', 'Glamer', '', 'Brd 3, Sor/Wiz 3', 'V, S, M', 'spellsHtoL.html#invisibility-sphere', 'Makes everyone within 10 ft. <a href="#" onClick="openLink(\'abilitiesAndConditions.html#invisible\');return false" style="color: rgb(87, 158, 182);">invisible</a>.'),
new Array('Invisibility, Greater', 'Illusion', 'Glamer', '', 'Brd 4, Sor/Wiz 4', 'V, S', 'spellsHtoL.html#greater-invisibility', 'As invisibility, but subject can attack and stay <a href="#" onClick="openLink(\'abilitiesAndConditions.html#invisible\');return false" style="color: rgb(87, 158, 182);">invisible</a>.'),
new Array('Invisibility, Mass', 'Illusion', 'Glamer', '', 'Sor/Wiz 7', 'V, S, M', 'spellsHtoL.html#mass-invisibility', 'As invisibility, but affects all in range.'),
new Array('Iron Body', 'Transmutation', '', '', 'Earth 8, Sor/Wiz 8', 'V, S, M/DF', 'spellsHtoL.html#iron-body', 'Your body becomes living iron.'),
new Array('Ironwood', 'Transmutation', '', '', 'Drd 6', 'V, S, M', 'spellsHtoL.html#ironwood', 'Magic wood is strong as steel.'),
new Array('Irresistible Dance', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 6, Sor/Wiz 8', 'V', 'spellsHtoL.html#irresistible-dance', 'Forces subject to dance.'),
new Array('Jump', 'Transmutation', '', '', 'Drd 1, Rgr 1, Sor/Wiz 1', 'V, S, M', 'spellsHtoL.html#jump', 'Subject gets bonus on Jump checks.'),
new Array('Keen Edge', 'Transmutation', '', '', 'Sor/Wiz 3', 'V, S', 'spellsHtoL.html#keen-edge', 'Doubles normal weapon&#8217;s threat range.'),
new Array('Knock', 'Transmutation', '', '', 'Sor/Wiz 2', 'V', 'spellsHtoL.html#knock', 'Opens locked or magically sealed door.'),
new Array('Know Direction', 'Divination', '', '', 'Brd 0, Drd 0', 'V, S', 'spellsHtoL.html#know-direction', 'You discern north.'),
new Array('Legend Lore', 'Divination', '', '', 'Brd 4, Knowledge 7, Sor/Wiz 6', 'V, S, M, F', 'spellsHtoL.html#legend-lore', 'Lets you learn tales about a person, place, or thing.'),
new Array('Levitate', 'Transmutation', '', '', 'Sor/Wiz 2', 'V, S, F', 'spellsHtoL.html#levitate', 'Subject moves up and down at your direction.'),
new Array('Light', 'Evocation', '', 'Light', 'Brd 0, Clr 0, Drd 0, Sor/Wiz 0', 'V, M/DF', 'spellsHtoL.html#light', 'Object shines like a torch.'),
new Array('Lightning Bolt', 'Evocation', '', 'Electricity', 'Sor/Wiz 3', 'V, S, M', 'spellsHtoL.html#lightning-bolt', 'Electricity deals 1d6/level damage.'),
new Array('Limited Wish', 'Universal', '', '', 'Sor/Wiz 7', 'V, S, XP', 'spellsHtoL.html#limited-wish', 'Alters reality&#8212;within spell limits.'),
new Array('Liveoak', 'Transmutation', '', '', 'Drd 6', 'V, S', 'spellsHtoL.html#liveoak', 'Oak becomes treant guardian.'),
new Array('Locate Creature', 'Divination', '', '', 'Brd 4, Sor/Wiz 4', 'V, S, M', 'spellsHtoL.html#locate-creature', 'Indicates direction to familiar creature.'),
new Array('Locate Object', 'Divination', '', '', 'Brd 2, Clr 3, Sor/Wiz 2, Travel 2', 'V, S, F/DF', 'spellsHtoL.html#locate-object', 'Senses direction toward object (specific or type).'),
new Array('Longstrider', 'Transmutation', '', '', 'Drd 1, Rgr 1, Travel 1', 'V, S, M', 'spellsHtoL.html#longstrider', 'Your speed increases by 10 ft.'),
new Array('Lullaby', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 0', 'V, S', 'spellsHtoL.html#lullaby', 'Makes subject drowsy; &#8211;5 on <a href="#" onClick="openLink(\'SkillsAll.html#Spot\');return false" style="color: rgb(87, 158, 182);">Spot</a> and <a href="#" onClick="openLink(\'SkillsAll.html#Listen\');return false" style="color: rgb(87, 158, 182);">Listen</a> checks, &#8211;2 on Will saves against sleep.'),
new Array('Mage Armor', 'Conjuration', 'Creation', 'Force', 'Sor/Wiz 1', 'V, S, F', 'spellsMtoO.html#mage-armor', 'Gives subject +4 armor bonus.'),
new Array('Mage Hand', 'Transmutation', '', '', 'Brd 0, Sor/Wiz 0', 'V, S', 'spellsMtoO.html#mage-hand', '5-pound telekinesis.'),
new Array('Mage\'s Disjunction', 'Abjuration', '', '', 'Magic 9, Sor/Wiz 9', 'V', 'spellsMtoO.html#mages-disjunction', 'Dispels magic, disenchants magic items.'),
new Array('Mage\'s Faithful Hound', 'Conjuration', 'Creation', '', 'Sor/Wiz 5', 'V, S, M', 'spellsMtoO.html#mages-faithful-hound', 'Phantom dog can guard, attack.'),
new Array('Mage\'s Lucubration', 'Transmutation', '', '', 'Wiz 6', 'V, S', 'spellsMtoO.html#mages-lucubration', 'Wizard only. Recalls spell of 5th level or lower.'),
new Array('Mage\'s Magnificent Mansion', 'Conjuration', 'Creation', '', 'Sor/Wiz 7', 'V, S, F', 'spellsMtoO.html#mages-magnificent-mansion', 'Door leads to extradimensional mansion.'),
new Array('Mage\'s Private Sanctum', 'Abjuration', '', '', 'Sor/Wiz 5', 'V, S, M', 'spellsMtoO.html#mages-private-sanctum', 'Prevents anyone from viewing or scrying an area for 24 hours.'),
new Array('Mage\'s Sword', 'Evocation', '', 'Force', 'Sor/Wiz 7', 'V, S, F', 'spellsMtoO.html#mages-sword', 'Floating magic blade strikes opponents.'),
new Array('Magic Aura', 'Illusion', 'Glamer', '', 'Brd 1, Magic 1, Sor/Wiz 1', 'V, S, F', 'spellsMtoO.html#magic-aura', 'Alters object&#8217;s magic aura.'),
new Array('Magic Circle against Chaos', 'Abjuration', '', 'Lawful', 'Clr 3, Law 3, Pal 3, Sor/Wiz 3', 'V, S, M/DF', 'spellsMtoO.html#magic-circle-against-chaos', 'As protection spells, but 10-ft. radius and 10 min./level.'),
new Array('Magic Circle against Evil', 'Abjuration', '', 'Good', 'Clr 3, Good 3, Pal 3, Sor/Wiz 3', 'V, S, M/DF', 'spellsMtoO.html#magic-circle-against-evil', 'As protection from evil, but 10-ft. radius and 10 min./level.'),
new Array('Magic Circle against Good', 'Abjuration', '', 'Evil', 'Clr 3, Evil 3, Sor/Wiz 3', 'V, S, M/DF', 'spellsMtoO.html#magic-circle-against-good', 'As protection spells, but 10-ft. radius and 10 min./level.'),
new Array('Magic Circle against Law', 'Abjuration', '', 'Chaotic', 'Chaos 3, Clr 3, Sor/Wiz 3', 'V, S, M/DF', 'spellsMtoO.html#magic-circle-against-law', 'As protection spells, but 10-ft. radius and 10 min./level.'),
new Array('Magic Fang', 'Transmutation', '', '', 'Drd 1, Rgr 1', 'V, S, DF', 'spellsMtoO.html#magic-fang', 'One natural weapon of subject creature gets +1 on attack and damage rolls.'),
new Array('Magic Fang, Greater', 'Transmutation', '', '', 'Drd 3, Rgr 3', 'V, S, DF', 'spellsMtoO.html#greater-magic-fang', 'One natural weapon of subject creature gets +1/four levels on attack and damage rolls (max +5).'),
new Array('Magic Jar', 'Necromancy', '', '', 'Sor/Wiz 5', 'V, S, F', 'spellsMtoO.html#magic-jar', 'Enables possession of another creature.'),
new Array('Magic Missile', 'Evocation', '', 'Force', 'Sor/Wiz 1', 'V, S', 'spellsMtoO.html#magic-missile', '1d4+1 damage; +1 missile per two levels above 1st (max 5).'),
new Array('Magic Mouth', 'Illusion', 'Glamer', '', 'Brd 1, Sor/Wiz 2', 'V, S, M', 'spellsMtoO.html#magic-mouth', 'Speaks once when triggered.'),
new Array('Magic Stone', 'Transmutation', '', '', 'Clr 1, Drd 1, Earth 1', 'V, S, DF', 'spellsMtoO.html#magic-stone', 'Three stones gain +1 on attack, deal 1d6 +1 damage.'),
new Array('Magic Vestment', 'Transmutation', '', '', 'Clr 3, Strength 3, War 3', 'V, S, DF', 'spellsMtoO.html#magic-vestment', 'Armor or shield gains +1 enhancement per four levels.'),
new Array('Magic Weapon', 'Transmutation', '', '', 'Clr 1, Pal 1, Sor/Wiz 1, War 1', 'V, S, DF', 'spellsMtoO.html#magic-weapon', 'Weapon gains +1 bonus.'),
new Array('Magic Weapon, Greater', 'Transmutation', '', '', 'Clr 4, Pal 3, Sor/Wiz 3', 'V, S, M/DF', 'spellsMtoO.html#greater-magic-weapon', '+1/four levels (max +5).'),
new Array('Major Creation', 'Conjuration', 'Creation', '', 'Sor/Wiz 5', 'V, S, M', 'spellsMtoO.html#major-creation', 'As minor creation, plus stone and metal.'),
new Array('Major Image', 'Illusion', 'Figment', '', 'Brd 3, Sor/Wiz 3', 'V, S, F', 'spellsMtoO.html#major-image', 'As silent image, plus sound, smell and thermal effects.'),
new Array('Make Whole', 'Transmutation', '', '', 'Clr 2', 'V, S', 'spellsMtoO.html#make-whole', 'Repairs an object.'),
new Array('Mark of Justice', 'Necromancy', '', '', 'Clr 5, Pal 4', 'V, S, DF', 'spellsMtoO.html#mark-of-justice', 'Designates action that will trigger curse on subject.'),
new Array('Maze', 'Conjuration', 'Teleportation', '', 'Sor/Wiz 8', 'V, S', 'spellsMtoO.html#maze', 'Traps subject in extradimensional maze.'),
new Array('Meld into Stone', 'Transmutation', '', 'Earth', 'Clr 3, Drd 3', 'V, S, DF', 'spellsMtoO.html#meld-into-stone', 'You and your gear merge with stone.'),
new Array('Mending', 'Transmutation', '', '', 'Brd 0, Clr 0, Drd 0, Sor/Wiz 0', 'V, S', 'spellsMtoO.html#mending', 'Makes minor repairs on an object.'),
new Array('Message', 'Transmutation', '', 'Language-Dependent', 'Brd 0, Sor/Wiz 0', 'V, S, F', 'spellsMtoO.html#message', 'Whispered conversation at distance.'),
new Array('Meteor Swarm', 'Evocation', '', 'Fire', 'Sor/Wiz 9', 'V, S', 'spellsMtoO.html#meteor-swarm', 'Four exploding spheres each deal 6d6 fire damage.'),
new Array('Mind Blank', 'Abjuration', '', '', 'Protection 8, Sor/Wiz 8', 'V, S', 'spellsMtoO.html#mind-blank', 'Subject is immune to mental/emotional magic and scrying.'),
new Array('Mind Fog', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 5, Sor/Wiz 5', 'V, S', 'spellsMtoO.html#mind-fog', 'Subjects in fog get &#8211;10 to Wis and Will checks.'),
new Array('Minor Creation', 'Conjuration', 'Creation', '', 'Sor/Wiz 4', 'V, S, M', 'spellsMtoO.html#minor-creation', 'Creates one cloth or wood object.'),
new Array('Minor Image', 'Illusion', 'Figment', '', 'Brd 2, Sor/Wiz 2', 'V, S, F', 'spellsMtoO.html#minor-image', 'As silent image, plus some sound.'),
new Array('Miracle', 'Evocation', '', '', 'Clr 9, Luck 9', 'V, S, XP; see text', 'spellsMtoO.html#miracle', 'Requests a deity&#8217;s intercession.'),
new Array('Mirage Arcana', 'Illusion', 'Glamer', '', 'Brd 5, Sor/Wiz 5', 'V, S', 'spellsMtoO.html#mirage-arcana', 'As hallucinatory terrain, plus structures.'),
new Array('Mirror Image', 'Illusion', 'Figment', '', 'Brd 2, Sor/Wiz 2', 'V, S', 'spellsMtoO.html#mirror-image', 'Creates decoy duplicates of you (1d4 +1 per three levels, max 8).'),
new Array('Misdirection', 'Illusion', 'Glamer', '', 'Brd 2, Sor/Wiz 2', 'V, S', 'spellsMtoO.html#misdirection', 'Misleads divinations for one creature or object.'),
new Array('Mislead', 'Illusion', 'Figment, Glamer', '', 'Brd 5, Luck 6, Sor/Wiz 6, Trickery 6', 'S', 'spellsMtoO.html#mislead', 'Turns you <a href="#" onClick="openLink(\'abilitiesAndConditions.html#invisible\');return false" style="color: rgb(87, 158, 182);">invisible</a> and creates illusory double.'),
new Array('Mnemonic Enhancer', 'Transmutation', '', '', 'Wiz 4', 'V, S, M, F', 'spellsMtoO.html#mnemonic-enhancer', 'Wizard only. Prepares extra spells or retains one just cast.'),
new Array('Modify Memory', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 4', 'V, S', 'spellsMtoO.html#modify-memory', 'Changes 5 minutes of subject&#8217;s memories.'),
new Array('Moment of Prescience', 'Divination', '', '', 'Luck 8, Sor/Wiz 8', 'V, S', 'spellsMtoO.html#moment-of-prescience', 'You gain insight bonus on single attack roll, check, or save.'),
new Array('Mount', 'Conjuration', 'Summoning', '', 'Sor/Wiz 1', 'V, S, M', 'spellsMtoO.html#mount', 'Summons riding horse for 2 hours/level.'),
new Array('Move Earth', 'Transmutation', '', 'Earth', 'Drd 6, Sor/Wiz 6', 'V, S, M', 'spellsMtoO.html#move-earth', 'Digs trenches and build hills.'),
new Array('Neutralize Poison', 'Conjuration', 'Healing', '', 'Brd 4, Clr 4, Drd 3, Pal 4, Rgr 3', 'V, S, M/DF', 'spellsMtoO.html#neutralize-poison', 'Immunizes subject against poison, detoxifies venom in or on subject.'),
new Array('Nightmare', 'Illusion', 'Phantasm', 'Mind-Affecting, Evil', 'Brd 5, Sor/Wiz 5', 'V, S', 'spellsMtoO.html#nightmare', 'Sends vision dealing 1d10 damage, fatigue.'),
new Array('Nondetection', 'Abjuration', '', '', 'Rgr 4, Sor/Wiz 3, Trickery 3', 'V, S, M', 'spellsMtoO.html#nondetection', 'Hides subject from divination, scrying.'),
new Array('Obscure Object', 'Abjuration', '', '', 'Brd 1, Clr 3, Sor/Wiz 2', 'V, S, M/DF', 'spellsMtoO.html#obscure-object', 'Masks object against scrying.'),
new Array('Obscuring Mist', 'Conjuration', 'Creation', '', 'Air 1, Clr 1, Drd 1, Sor/Wiz 1, Water 1', 'V, S', 'spellsMtoO.html#obscuring-mist', 'Fog surrounds you.'),
new Array('Open/Close', 'Transmutation', '', '', 'Brd 0, Sor/Wiz 0', 'V, S, F', 'spellsMtoO.html#open/close', 'Opens or closes small or light things.'),
new Array('Order\'s Wrath', 'Evocation', '', 'Lawful', 'Law 4', 'V, S', 'spellsMtoO.html#orders-wrath', 'Damages and dazes chaotic creatures.'),
new Array('Overland Flight', 'Transmutation', '', '', 'Sor/Wiz 5', 'V, S', 'spellsMtoO.html#overland-flight', 'You fly at a speed of 40 ft. and can hustle over long distances.'),
new Array('Owl\'s Wisdom', 'Transmutation', '', '', 'Clr 2, Drd 2, Pal 2, Rgr 2, Sor/Wiz 2', 'V, S, M/DF', 'spellsMtoO.html#owls-wisdom', 'Subject gains +4 to Wis for 1 min./level.'),
new Array('Owl\'s Wisdom, Mass', 'Transmutation', '', '', 'Clr 6, Drd 6, Sor/Wiz 6', 'V, S, M/DF', 'spellsMtoO.html#mass-owls-wisdom', 'As owl&#8217;s wisdom, affects one subject/ level.'),
new Array('Pass without Trace', 'Transmutation', '', '', 'Drd 1, Rgr 1', 'V, S, DF', 'spellsPtoR.html#pass-without-trace', 'One subject/level leaves no tracks.'),
new Array('Passwall', 'Transmutation', '', '', 'Sor/Wiz 5', 'V, S, M', 'spellsPtoR.html#passwall', 'Creates passage through wood or stone wall.'),
new Array('Permanency', 'Universal', '', '', 'Sor/Wiz 5', 'V, S, XP', 'spellsPtoR.html#permanency', 'Makes certain spells permanent.'),
new Array('Permanent Image', 'Illusion', 'Figment', '', 'Brd 6, Sor/Wiz 6', 'V, S, F', 'spellsPtoR.html#permanent-image', 'Includes sight, sound, and smell.'),
new Array('Persistent Image', 'Illusion', 'Figment', '', 'Brd 5, Sor/Wiz 5', 'V, S, F', 'spellsPtoR.html#persistent-image', 'As major image, but no concentration required.'),
new Array('Phantasmal Killer', 'Illusion', 'Phantasm', 'Fear, Mind-Affecting', 'Sor/Wiz 4', 'V, S', 'spellsPtoR.html#phantasmal-killer', 'Fearsome illusion kills subject or deals 3d6 damage.'),
new Array('Phantom Steed', 'Conjuration', 'Creation', '', 'Brd 3, Sor/Wiz 3', 'V, S', 'spellsPtoR.html#phantom-steed', 'Magic horse appears for 1 hour/level.'),
new Array('Phantom Trap', 'Illusion', 'Glamer', '', 'Sor/Wiz 2', 'V, S, M', 'spellsPtoR.html#phantom-trap', 'Makes item seem trapped.'),
new Array('Phase Door', 'Conjuration', 'Creation', '', 'Sor/Wiz 7, Travel 8', 'V', 'spellsPtoR.html#phase-door', 'Creates an <a href="#" onClick="openLink(\'abilitiesAndConditions.html#invisible\');return false" style="color: rgb(87, 158, 182);">invisible</a> passage through wood or stone.'),
new Array('Planar Ally', 'Conjuration', 'Calling', 'see text for lesser planar ally', 'Clr 6', 'V, S, DF, XP', 'spellsPtoR.html#planar-ally', 'As lesser planar ally, but up to 12 HD.'),
new Array('Planar Ally, Greater', 'Conjuration', 'Calling', 'see text for lesser planar ally', 'Clr 8', 'V, S, DF, XP', 'spellsPtoR.html#greater-planar-ally', 'As lesser planar ally, but up to 18 HD.'),
new Array('Planar Ally, Lesser', 'Conjuration', 'Calling', 'see text', 'Clr 4', 'V, S, DF, XP', 'spellsPtoR.html#lesser-planar-ally', 'Exchange services with a 6 HD extraplanar creature.'),
new Array('Planar Binding', 'Conjuration', 'Calling', 'see text for lesser planar binding', 'Sor/Wiz 6', 'V, S', 'spellsPtoR.html#planar-binding', 'As lesser planar binding, but up to 12 HD.'),
new Array('Planar Binding, Greater', 'Conjuration', 'Calling', 'see text for lesser planar binding', 'Sor/Wiz 8', 'V, S', 'spellsPtoR.html#greater-planar-binding', 'As lesser planar binding, but up to 18 HD.'),
new Array('Planar Binding, Lesser', 'Conjuration', 'Calling', 'see text', 'Sor/Wiz 5', 'V, S', 'spellsPtoR.html#lesser-planar-binding', 'Traps extraplanar creature of 6 HD or less until it performs a task.'),
new Array('Plane Shift', 'Conjuration', 'Teleportation', '', 'Clr 5, Sor/Wiz 7', 'V, S, F', 'spellsPtoR.html#plane-shift', 'As many as eight subjects travel to another plane.'),
new Array('Plant Growth', 'Transmutation', '', '', 'Drd 3, Plant 3, Rgr 3', 'V, S, DF', 'spellsPtoR.html#plant-growth', 'Grows vegetation, improves crops.'),
new Array('Poison', 'Necromancy', '', '', 'Clr 4, Drd 3', 'V, S, DF', 'spellsPtoR.html#poison', 'Touch deals 1d10 Con damage, repeats in 1 min.'),
new Array('Polar Ray', 'Evocation', '', 'Cold', 'Sor/Wiz 8', 'V, S, F', 'spellsPtoR.html#polar-ray', 'Ranged touch attack deals 1d6/level cold damage.'),
new Array('Polymorph', 'Transmutation', '', '', 'Sor/Wiz 4', 'V, S, M', 'spellsPtoR.html#polymorph', 'Gives one willing subject a new form.'),
new Array('Polymorph Any Object', 'Transmutation', '', '', 'Sor/Wiz 8, Trickery 8', 'V, S, M/DF', 'spellsPtoR.html#polymorph-any-object', 'Changes any subject into anything else.'),
new Array('Power Word Blind', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Sor/Wiz 7, War 7', 'V', 'spellsPtoR.html#power-word-blind', '<a href="#" onClick="openLink(\'abilitiesAndConditions.html#blinded\');return false" style="color: rgb(87, 158, 182);">Blinds</a> creature with 200 hp or less.'),
new Array('Power Word Kill', 'Enchantment', 'Compulsion', 'Death, Mind-Affecting', 'Sor/Wiz 9, War 9', 'V', 'spellsPtoR.html#power-word-kill', 'Kills one creature with 100 hp or less.'),
new Array('Power Word Stun', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Sor/Wiz 8, War 8', 'V', 'spellsPtoR.html#power-word-stun', 'Stuns creature with 150 hp or less.'),
new Array('Prayer', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Clr 3, Pal 3', 'V, S, DF', 'spellsPtoR.html#prayer', 'Allies +1 bonus on most rolls, enemies &#8211;1 penalty.'),
new Array('Prestidigitation', 'Universal', '', '', 'Brd 0, Sor/Wiz 0', 'V, S', 'spellsPtoR.html#prestidigitation', 'Performs minor tricks.'),
new Array('Prismatic Sphere', 'Abjuration', '', '', 'Protection 9, Sor/Wiz 9, Sun 9', 'V', 'spellsPtoR.html#prismatic-sphere', 'As prismatic wall, but surrounds on all sides.'),
new Array('Prismatic Spray', 'Evocation', '', '', 'Sor/Wiz 7', 'V, S', 'spellsPtoR.html#prismatic-spray', 'Rays hit subjects with variety of effects.'),
new Array('Prismatic Wall', 'Abjuration', '', '', 'Sor/Wiz 8', 'V, S', 'spellsPtoR.html#prismatic-wall', 'Wall&#8217;s colors have array of effects.'),
new Array('Produce Flame', 'Evocation', '', 'Fire', 'Drd 1, Fire 2', 'V, S', 'spellsPtoR.html#produce-flame', '1d6 damage +1/level, touch or thrown.'),
new Array('Programmed Image', 'Illusion', 'Figment', '', 'Brd 6, Sor/Wiz 6', 'V, S, F', 'spellsPtoR.html#programmed-image', 'As major image, plus triggered by event.'),
new Array('Project Image', 'Illusion', 'Shadow', '', 'Brd 6, Sor/Wiz 7', 'V, S, M', 'spellsPtoR.html#project-image', 'Illusory double can talk and cast spells.'),
new Array('Protection from Arrows', 'Abjuration', '', '', 'Sor/Wiz 2', 'V, S, F', 'spellsPtoR.html#protection-from-arrows', 'Subject immune to most ranged attacks.'),
new Array('Protection from Chaos', 'Abjuration', '', 'Lawful', 'Clr 1, Law 1, Pal 1, Sor/Wiz 1', 'V, S, M/DF', 'spellsPtoR.html#protection-from-chaos', '+2 to AC and saves, counter mind control, hedge out elementals and outsiders.'),
new Array('Protection from Energy', 'Abjuration', '', '', 'Clr 3, Drd 3, Luck 3, Protection 3, Rgr 2, Sor/Wiz 3', 'V, S, DF', 'spellsPtoR.html#protection-from-energy', 'Absorb 12 points/level of damage from one kind of energy.'),
new Array('Protection from Evil', 'Abjuration', '', 'Good', 'Clr 1, Good 1, Pal 1, Sor/Wiz 1', 'V, S, M/DF', 'spellsPtoR.html#protection-from-evil', '+2 to AC and saves, counter mind control, hedge out elementals and outsiders.'),
new Array('Protection from Good', 'Abjuration', '', 'Evil', 'Clr 1, Evil 1, Sor/Wiz 1', 'V, S, M/DF', 'spellsPtoR.html#protection-from-good', '+2 to AC and saves, counter mind control, hedge out elementals and outsiders.'),
new Array('Protection from Law', 'Abjuration', '', 'Chaotic', 'Chaos 1, Clr 1, Sor/Wiz 1', 'V, S, M/DF', 'spellsPtoR.html#protection-from-law', '+2 to AC and saves, counter mind control, hedge out elementals and outsiders.'),
new Array('Protection from Spells', 'Abjuration', '', '', 'Magic 8, Sor/Wiz 8', 'V, S, M, F', 'spellsPtoR.html#protection-from-spells', 'Confers +8 resistance bonus.'),
new Array('Prying Eyes', 'Divination', '', '', 'Sor/Wiz 5', 'V, S, M', 'spellsPtoR.html#prying-eyes', '1d4 +1/level floating eyes scout for you.'),
new Array('Prying Eyes, Greater', 'Divination', '', '', 'Sor/Wiz 8', 'V, S, M', 'spellsPtoR.html#greater-prying-eyes', 'As prying eyes, but eyes have true seeing.'),
new Array('Purify Food and Drink', 'Transmutation', '', '', 'Clr 0, Drd 0', 'V, S', 'spellsPtoR.html#purify-food-and-drink', 'Purifies 1 cu. ft./level of food or water.'),
new Array('Pyrotechnics', 'Transmutation', '', '', 'Brd 2, Sor/Wiz 2', 'V, S, M', 'spellsPtoR.html#pyrotechnics', 'Turns fire into <a href="#" onClick="openLink(\'abilitiesAndConditions.html#blinded\');return false" style="color: rgb(87, 158, 182);">blinding</a> light or choking smoke.'),
new Array('Quench', 'Transmutation', '', '', 'Drd 3', 'V, S, DF', 'spellsPtoR.html#quench', 'Extinguishes nonmagical fires or one magic item.'),
new Array('Rage', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 2, Sor/Wiz 3', 'V, S', 'spellsPtoR.html#rage', 'Subjects gains +2 to Str and Con, +1 on Will saves, &#8211;2 to AC.'),
new Array('Rainbow Pattern', 'Illusion', 'Pattern', 'Mind-Affecting', 'Brd 4, Sor/Wiz 4', 'V (Brd only), S, M, F; see text', 'spellsPtoR.html#rainbow-pattern', 'Lights fascinate 24 HD of creatures.'),
new Array('Raise Dead', 'Conjuration', 'Healing', '', 'Clr 5', 'V, S, M, DF', 'spellsPtoR.html#raise-dead', 'Restores life to subject who died as long as one day/level ago.'),
new Array('Ray of Enfeeblement', 'Necromancy', '', '', 'Sor/Wiz 1', 'V, S', 'spellsPtoR.html#ray-of-enfeeblement', 'Ray deals 1d6 +1 per two levels Str damage.'),
new Array('Ray of Exhaustion', 'Necromancy', '', '', 'Sor/Wiz 3', 'V, S, M', 'spellsPtoR.html#ray-of-exhaustion', 'Ray makes subject <a href="#" onClick="openLink(\'abilitiesAndConditions.html#exhausted\');return false" style="color: rgb(87, 158, 182);">exhausted</a>.'),
new Array('Ray of Frost', 'Evocation', '', 'Cold', 'Sor/Wiz 0', 'V, S', 'spellsPtoR.html#ray-of-frost', 'Ray deals 1d3 cold damage.'),
new Array('Read Magic', 'Divination', '', '', 'Brd 0, Clr 0, Drd 0, Pal 1, Rgr 1, Sor/Wiz 0', 'V, S, F', 'spellsPtoR.html#read-magic', 'Read scrolls and spellbooks.'),
new Array('Reduce Animal', 'Transmutation', '', '', 'Drd 2, Rgr 3', 'V, S', 'spellsPtoR.html#reduce-animal', 'Shrinks one willing animal.'),
new Array('Reduce Person', 'Transmutation', '', '', 'Sor/Wiz 1', 'V, S, M', 'spellsPtoR.html#reduce-person', 'Humanoid creature halves in size.'),
new Array('Reduce Person, Mass', 'Transmutation', '', '', 'Sor/Wiz 4', 'V, S, M', 'spellsPtoR.html#mass-reduce-person', 'Reduces several creatures.'),
new Array('Refuge', 'Conjuration', 'Teleportation', '', 'Clr 7, Sor/Wiz 9', 'V, S, M', 'spellsPtoR.html#refuge', 'Alters item to transport its possessor to you.'),
new Array('Regenerate', 'Conjuration', 'Healing', '', 'Clr 7, Drd 9, Healing 7', 'V, S, DF', 'spellsPtoR.html#regenerate', 'Subject&#8217;s severed limbs grow back, cures 4d8 damage +1/level (max +35).'),
new Array('Reincarnate', 'Transmutation', '', '', 'Drd 4', 'V, S, M, DF', 'spellsPtoR.html#reincarnate', 'Brings <a href="#" onClick="openLink(\'abilitiesAndConditions.html#dead\');return false" style="color: rgb(87, 158, 182);">dead</a> subject back in a random body.'),
new Array('Remove Blindness/Deafness', 'Conjuration', 'Healing', '', 'Clr 3, Pal 3', 'V, S', 'spellsPtoR.html#remove-blindness/deafness', 'Cures normal or magical conditions.'),
new Array('Remove Curse', 'Abjuration', '', '', 'Brd 3, Clr 3, Pal 3, Sor/Wiz 4', 'V, S', 'spellsPtoR.html#remove-curse', 'Frees object or person from curse.'),
new Array('Remove Disease', 'Conjuration', 'Healing', '', 'Clr 3, Drd 3, Rgr 3', 'V, S', 'spellsPtoR.html#remove-disease', 'Cures all diseases affecting subject.'),
new Array('Remove Fear', 'Abjuration', '', '', 'Brd 1, Clr 1', 'V, S', 'spellsPtoR.html#remove-fear', 'Suppresses fear or gives +4 on saves against fear for one subject + one per four levels.'),
new Array('Remove Paralysis', 'Conjuration', 'Healing', '', 'Clr 2, Pal 2', 'V, S', 'spellsPtoR.html#remove-paralysis', 'Frees one or more creatures from paralysis or slow effect.'),
new Array('Repel Metal or Stone', 'Abjuration', '', 'Earth', 'Drd 8', 'V, S', 'spellsPtoR.html#repel-metal-or-stone', 'Pushes away metal and stone.'),
new Array('Repel Vermin', 'Abjuration', '', '', 'Brd 4, Clr 4, Drd 4, Rgr 3', 'V, S, DF', 'spellsPtoR.html#repel-vermin', 'Insects, spiders, and other vermin stay 10 ft. away.'),
new Array('Repel Wood', 'Transmutation', '', '', 'Drd 6, Plant 6', 'V, S', 'spellsPtoR.html#repel-wood', 'Pushes away wooden objects.'),
new Array('Repulsion', 'Abjuration', '', '', 'Clr 7, Protection 7, Sor/Wiz 6', 'V, S, F/DF', 'spellsPtoR.html#repulsion', 'Creatures can&#8217;t approach you.'),
new Array('Resilient Sphere', 'Evocation', '', 'Force', 'Sor/Wiz 4', 'V, S, M', 'spellsPtoR.html#resilient-sphere', 'Force globe protects but traps one subject.'),
new Array('Resist Energy', 'Abjuration', '', '', 'Clr 2, Drd 2, Fire 3, Pal 2, Rgr 1, Sor/Wiz 2', 'V, S, DF', 'spellsPtoR.html#resist-energy', 'Ignores first 10 (or more) points of damage/attack from specified energy type.'),
new Array('Resistance', 'Abjuration', '', '', 'Brd 0, Clr 0, Drd 0, Pal 1, Sor/Wiz 0', 'V, S, M/DF', 'spellsPtoR.html#resistance', 'Subject gains +1 on saving throws.'),
new Array('Restoration', 'Conjuration', 'Healing', '', 'Clr 4, Pal 4', 'V, S, M', 'spellsPtoR.html#restoration', 'Restores level and ability score <a href="#" onClick="openLink(\'abilitiesAndConditions.html#ability-drained\');return false" style="color: rgb(87, 158, 182);">drains</a>.'),
new Array('Restoration, Greater', 'Conjuration', 'Healing', '', 'Clr 7', 'V, S, XP', 'spellsPtoR.html#greater-restoration', 'As restoration, plus restores all levels and ability scores.'),
new Array('Restoration, Lesser', 'Conjuration', 'Healing', '', 'Clr 2, Drd 2, Pal 1', 'V, S', 'spellsPtoR.html#lesser-restoration', 'Dispels magical ability penalty or repairs 1d4 <a href="#" onClick="openLink(\'abilitiesAndConditions.html#ability-damaged\');return false" style="color: rgb(87, 158, 182);">ability damage</a>.'),
new Array('Resurrection', 'Conjuration', 'Healing', '', 'Clr 7', 'V, S, M, DF', 'spellsPtoR.html#resurrection', 'Fully restore <a href="#" onClick="openLink(\'abilitiesAndConditions.html#dead\');return false" style="color: rgb(87, 158, 182);">dead</a> subject.'),
new Array('Reverse Gravity', 'Transmutation', '', '', 'Drd 8, Sor/Wiz 7', 'V, S, M/DF', 'spellsPtoR.html#reverse-gravity', 'Objects and creatures fall upward.'),
new Array('Righteous Might', 'Transmutation', '', '', 'Clr 5, Strength 5', 'V, S, DF', 'spellsPtoR.html#righteous-might', 'Your size increases, and you gain combat bonuses.'),
new Array('Rope Trick', 'Transmutation', '', '', 'Sor/Wiz 2', 'V, S, M', 'spellsPtoR.html#rope-trick', 'As many as eight creatures hide in extradimensional space.'),
new Array('Rusting Grasp', 'Transmutation', '', '', 'Drd 4', 'V, S, DF', 'spellsPtoR.html#rusting-grasp', 'Your touch corrodes iron and alloys.'),
new Array('Sanctuary', 'Abjuration', '', '', 'Clr 1, Protection 1', 'V, S, DF', 'spellsS.html#sanctuary', 'Opponents can&#8217;t attack you, and you can&#8217;t attack.'),
new Array('Scare', 'Necromancy', '', 'Fear, Mind-Affecting', 'Brd 2, Sor/Wiz 2', 'V, S, M', 'spellsS.html#scare', 'Panics creatures of less than 6 HD.'),
new Array('Scintillating Pattern', 'Illusion', 'Pattern', 'Mind-Affecting', 'Sor/Wiz 8', 'V, S, M', 'spellsS.html#scintillating-pattern', 'Twisting colors confuse, stun, or render <a href="#" onClick="openLink(\'abilitiesAndConditions.html#unconscious\');return false" style="color: rgb(87, 158, 182);">unconscious</a>.'),
new Array('Scorching Ray', 'Evocation', '', 'Fire', 'Sor/Wiz 2', 'V, S', 'spellsS.html#scorching-ray', 'Ranged touch attack deals 4d6 fire damage, +1 ray/four levels (max 3).'),
new Array('Screen', 'Illusion', 'Glamer', '', 'Sor/Wiz 8, Trickery 7', 'V, S', 'spellsS.html#screen', 'Illusion hides area from vision, scrying.'),
new Array('Scrying', 'Divination', 'Scrying', '', 'Brd 3, Clr 5, Drd 4, Sor/Wiz 4', 'V, S, M/DF, F', 'spellsS.html#scrying', 'Spies on subject from a distance.'),
new Array('Scrying, Greater', 'Divination', 'Scrying', '', 'Brd 6, Clr 7, Drd 7, Sor/Wiz 7', 'V, S', 'spellsS.html#greater-scrying', 'As scrying, but faster and longer.'),
new Array('Sculpt Sound', 'Transmutation', '', '', 'Brd 3', 'V, S', 'spellsS.html#sculpt-sound', 'Creates new sounds or changes existing ones.'),
new Array('Searing Light', 'Evocation', '', '', 'Clr 3, Sun 3', 'V, S', 'spellsS.html#searing-light', 'Ray deals 1d8/two levels damage, more against undead.'),
new Array('Secret Chest', 'Conjuration', 'Summoning', '', 'Sor/Wiz 5', 'V, S, F', 'spellsS.html#secret-chest', 'Hides expensive chest on Ethereal Plane; you retrieve it at will.'),
new Array('Secret Page', 'Transmutation', '', '', 'Brd 3, Sor/Wiz 3', 'V, S, M', 'spellsS.html#secret-page', 'Changes one page to hide its real content.'),
new Array('Secure Shelter', 'Conjuration', 'Creation', '', 'Brd 4, Sor/Wiz 4', 'V, S, M, F; see text', 'spellsS.html#secure-shelter', 'Creates sturdy cottage.'),
new Array('See Invisibility', 'Divination', '', '', 'Brd 3, Sor/Wiz 2', 'V, S, M', 'spellsS.html#see-invisibility', 'Reveals <a href="#" onClick="openLink(\'abilitiesAndConditions.html#invisible\');return false" style="color: rgb(87, 158, 182);">invisible</a> creatures or objects.'),
new Array('Seeming', 'Illusion', 'Glamer', '', 'Brd 5, Sor/Wiz 5', 'V, S', 'spellsS.html#seeming', 'Changes appearance of one person per two levels.'),
new Array('Sending', 'Evocation', '', '', 'Clr 4, Sor/Wiz 5', 'V, S, M/DF', 'spellsS.html#sending', 'Delivers short message anywhere, instantly.'),
new Array('Sepia Snake Sigil', 'Conjuration', 'Creation', 'Force', 'Brd 3, Sor/Wiz 3', 'V, S, M', 'spellsS.html#sepia-snake-sigil', 'Creates text symbol that immobilizes reader.'),
new Array('Sequester', 'Abjuration', '', '', 'Sor/Wiz 7', 'V, S, M', 'spellsS.html#sequester', 'Subject is <a href="#" onClick="openLink(\'abilitiesAndConditions.html#invisible\');return false" style="color: rgb(87, 158, 182);">invisible</a> to sight and scrying; renders creature comatose.'),
new Array('Shades', 'Illusion', 'Shadow', '', 'Sor/Wiz 9', 'V, S', 'spellsS.html#shades', 'As shadow conjuration, but up to 8th level and 80% real.'),
new Array('Shadow Conjuration', 'Illusion', 'Shadow', '', 'Brd 4, Sor/Wiz 4', 'V, S', 'spellsS.html#shadow-conjuration', 'Mimics conjuration below 4th level, but only 20% real.'),
new Array('Shadow Conjuration, Greater', 'Illusion', 'Shadow', '', 'Sor/Wiz 7', 'V, S', 'spellsS.html#greater-shadow-conjuration', 'As shadow conjuration, but up to 6th level and 60% real.'),
new Array('Shadow Evocation', 'Illusion', 'Shadow', '', 'Brd 5, Sor/Wiz 5', 'V, S', 'spellsS.html#shadow-evocation', 'Mimics evocation below 5th level, but only 20% real.'),
new Array('Shadow Evocation, Greater', 'Illusion', 'Shadow', '', 'Sor/Wiz 8', 'V, S', 'spellsS.html#greater-shadow-evocation', 'As shadow evocation, but up to 7th level and 60% real.'),
new Array('Shadow Walk', 'Illusion', 'Shadow', '', 'Brd 5, Sor/Wiz 6', 'V, S', 'spellsS.html#shadow-walk', 'Step into shadow to travel rapidly.'),
new Array('Shambler', 'Conjuration', 'Creation', '', 'Drd 9, Plant 9', 'V, S', 'spellsS.html#shambler', 'Summons 1d4+2 shambling mounds to fight for you.'),
new Array('Shapechange', 'Transmutation', '', '', 'Animal 9, Drd 9, Sor/Wiz 9', 'V, S, F', 'spellsS.html#shapechange', 'Transforms you into any creature, and change forms once per round.'),
new Array('Shatter', 'Evocation', '', 'Sonic', 'Brd 2, Chaos 2, Clr 2, Destruction 2, Sor/Wiz 2', 'V, S, M/DF', 'spellsS.html#shatter', 'Sonic vibration damages objects or crystalline creatures.'),
new Array('Shield', 'Abjuration', '', 'Force', 'Sor/Wiz 1', 'V, S', 'spellsS.html#shield', 'Invisible disc gives +4 to AC, blocks magic missiles.'),
new Array('Shield Other', 'Abjuration', '', '', 'Clr 2, Pal 2, Protection 2', 'V, S, F', 'spellsS.html#shield-other', 'You take half of subject&#8217;s damage.'),
new Array('Shield of Faith', 'Abjuration', '', '', 'Clr 1', 'V, S, M', 'spellsS.html#shield-of-faith', 'Aura grants +2 or higher deflection bonus.'),
new Array('Shield of Law', 'Abjuration', '', 'Lawful', 'Clr 8, Law 8', 'V, S, F', 'spellsS.html#shield-of-law', '+4 to AC, +4 resistance, and SR 25 against chaotic spells.'),
new Array('Shillelagh', 'Transmutation', '', '', 'Drd 1', 'V, S, DF', 'spellsS.html#shillelagh', 'Cudgel or quarterstaff becomes +1 weapon (1d10 damage) for 1 min./level.'),
new Array('Shocking Grasp', 'Evocation', '', 'Electricity', 'Sor/Wiz 1', 'V, S', 'spellsS.html#shocking-grasp', 'Touch delivers 1d6/level electricity damage (max 5d6).'),
new Array('Shout', 'Evocation', '', 'Sonic', 'Brd 4, Sor/Wiz 4', 'V', 'spellsS.html#shout', 'Deafens all within cone and deals 5d6 sonic damage.'),
new Array('Shout, Greater', 'Evocation', '', 'Sonic', 'Brd 6, Sor/Wiz 8', 'V, S, F', 'spellsS.html#greater-shout', 'Devastating yell deals 10d6 sonic damage; stuns creatures, damages objects.'),
new Array('Shrink Item', 'Transmutation', '', '', 'Sor/Wiz 3', 'V, S', 'spellsS.html#shrink-item', 'Object shrinks to one-sixteenth size.'),
new Array('Silence', 'Illusion', 'Glamer', '', 'Brd 2, Clr 2', 'V, S', 'spellsS.html#silence', 'Negates sound in 15-ft. radius.'),
new Array('Silent Image', 'Illusion', 'Figment', '', 'Brd 1, Sor/Wiz 1', 'V, S, F', 'spellsS.html#silent-image', 'Creates minor illusion of your design.'),
new Array('Simulacrum', 'Illusion', 'Shadow', '', 'Sor/Wiz 7', 'V, S, M, XP', 'spellsS.html#simulacrum', 'Creates partially real double of a creature.'),
new Array('Slay Living', 'Necromancy', '', 'Death', 'Clr 5, Death 5', 'V, S', 'spellsS.html#slay-living', 'Touch attack kills subject.'),
new Array('Sleep', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Brd 1, Sor/Wiz 1', 'V, S, M', 'spellsS.html#sleep', 'Puts 4 HD of creatures into magical slumber.'),
new Array('Sleet Storm', 'Conjuration', 'Creation', 'Cold', 'Drd 3, Sor/Wiz 3', 'V, S, M/DF', 'spellsS.html#sleet-storm', 'Hampers vision and movement.'),
new Array('Slow', 'Transmutation', '', '', 'Brd 3, Sor/Wiz 3', 'V, S, M', 'spellsS.html#slow', 'One subject/level takes only one action/round, &#8211;2 to AC, &#8211;2 on attack rolls.'),
new Array('Snare', 'Transmutation', '', '', 'Rgr 2, Drd 3', 'V, S, DF', 'spellsS.html#snare', 'Creates a magic booby trap.'),
new Array('Soften Earth and Stone', 'Transmutation', '', 'Earth', 'Drd 2, Earth 2', 'V, S, DF', 'spellsS.html#soften-earth-and-stone', 'Turns stone to clay or dirt to sand or mud.'),
new Array('Solid Fog', 'Conjuration', 'Creation', '', 'Sor/Wiz 4', 'V, S, M', 'spellsS.html#solid-fog', 'Blocks vision and slows movement.'),
new Array('Song of Discord', 'Enchantment', 'Compulsion', 'Mind-Affecting, Sonic', 'Brd 5', 'V, S', 'spellsS.html#song-of-discord', 'Forces targets to attack each other.'),
new Array('Soul Bind', 'Necromancy', '', '', 'Clr 9, Sor/Wiz 9', 'V, S, F', 'spellsS.html#soul-bind', 'Traps newly <a href="#" onClick="openLink(\'abilitiesAndConditions.html#dead\');return false" style="color: rgb(87, 158, 182);">dead</a> soul to prevent resurrection.'),
new Array('Sound Burst', 'Evocation', '', 'Sonic', 'Brd 2, Clr 2', 'V, S, F/DF', 'spellsS.html#sound-burst', 'Deals 1d8 sonic damage to subjects; may stun them.'),
new Array('Speak with Animals', 'Divination', '', '', 'Brd 3, Drd 1, Rgr 1', 'V, S', 'spellsS.html#speak-with-animals', 'You can communicate with animals.'),
new Array('Speak with Dead', 'Necromancy', '', 'Language-Dependent', 'Clr 3', 'V, S, DF', 'spellsS.html#speak-with-dead', 'Corpse answers one question/two levels.'),
new Array('Speak with Plants', 'Divination', '', '', 'Brd 4, Drd 3, Rgr 2', 'V, S', 'spellsS.html#speak-with-plants', 'You can talk to normal plants and plant creatures.'),
new Array('Spectral Hand', 'Necromancy', '', '', 'Sor/Wiz 2', 'V, S', 'spellsS.html#spectral-hand', 'Creates disembodied glowing hand to deliver touch attacks.'),
new Array('Spell Immunity', 'Abjuration', '', '', 'Clr 4, Protection 4, Strength 4', 'V, S, DF', 'spellsS.html#spell-immunity', 'Subject is immune to one spell per four levels.'),
new Array('Spell Immunity, Greater', 'Abjuration', '', '', 'Clr 8', 'V, S, DF', 'spellsS.html#greater-spell-immunity', 'As spell immunity, but up to 8th-level spells.'),
new Array('Spell Resistance', 'Abjuration', '', '', 'Clr 5, Magic 5, Protection 5', 'V, S, DF', 'spellsS.html#spell-resistance', 'Subject gains SR 12 + level.'),
new Array('Spell Turning', 'Abjuration', '', '', 'Luck 7, Magic 7, Sor/Wiz 7', 'V, S, M/DF', 'spellsS.html#spell-turning', 'Reflect 1d4+6 spell levels back at caster.'),
new Array('Spellstaff', 'Transmutation', '', '', 'Drd 6', 'V, S, F', 'spellsS.html#spellstaff', 'Stores one spell in wooden quarterstaff.'),
new Array('Spider Climb', 'Transmutation', '', '', 'Drd 2, Sor/Wiz 2', 'V, S, M', 'spellsS.html#spider-climb', 'Grants ability to walk on walls and ceilings.'),
new Array('Spike Growth', 'Transmutation', '', '', 'Drd 3, Rgr 2', 'V, S, DF', 'spellsS.html#spike-growth', 'Creatures in area take 1d4 damage, may be slowed.'),
new Array('Spike Stones', 'Transmutation', '', 'Earth', 'Drd 4, Earth 4', 'V, S, DF', 'spellsS.html#spike-stones', 'Creatures in area take 1d8 damage, may be slowed.'),
new Array('Spiritual Weapon', 'Evocation', '', 'Force', 'Clr 2, War 2', 'V, S, DF', 'spellsS.html#spiritual-weapon', 'Magic weapon attacks on its own.'),
new Array('Statue', 'Transmutation', '', '', 'Sor/Wiz 7', 'V, S, M', 'spellsS.html#statue', 'Subject can become a statue at will.'),
new Array('Status', 'Divination', '', '', 'Clr 2', 'V, S', 'spellsS.html#status', 'Monitors condition, position of allies.'),
new Array('Stinking Cloud', 'Conjuration', 'Creation', '', 'Sor/Wiz 3', 'V, S, M', 'spellsS.html#stinking-cloud', 'Nauseating vapors, 1 round/level.'),
new Array('Stone Shape', 'Transmutation', '', 'Earth', 'Clr 3, Drd 3, Earth 3, Sor/Wiz 5', 'V, S, M/DF', 'spellsS.html#stone-shape', 'Sculpts stone into any shape.'),
new Array('Stone Tell', 'Divination', '', '', 'Drd 6', 'V, S, DF', 'spellsS.html#stone-tell', 'Talk to natural or worked stone.'),
new Array('Stone to Flesh', 'Transmutation', '', '', 'Sor/Wiz 6', 'V, S, M', 'spellsS.html#stone-to-flesh', 'Restores <a href="#" onClick="openLink(\'abilitiesAndConditions.html#petrified\');return false" style="color: rgb(87, 158, 182);">petrified</a> creature.'),
new Array('Stoneskin', 'Abjuration', '', '', 'Drd 5, Earth 6, Sor/Wiz 4, Strength 6', 'V, S, M', 'spellsS.html#stoneskin', 'Ignore 10 points of damage per attack.'),
new Array('Storm of Vengeance', 'Conjuration', 'Summoning', '', 'Drd 9, Clr 9', 'V, S', 'spellsS.html#storm-of-vengeance', 'Storm rains acid, lightning, and hail.'),
new Array('Suggestion', 'Enchantment', 'Compulsion', 'Language-Dependent, Mind-Affecting', 'Brd 2, Sor/Wiz 3', 'V, M', 'spellsS.html#suggestion', 'Compels subject to follow stated course of action.'),
new Array('Suggestion, Mass', 'Enchantment', 'Compulsion', 'Language-Dependent, Mind-Affecting', 'Brd 5, Sor/Wiz 6', 'V, M', 'spellsS.html#mass-suggestion', 'As suggestion, plus one subject/level.'),
new Array('Summon Instrument', 'Conjuration', 'Summoning', '', 'Brd 0', 'V, S', 'spellsS.html#summon-instrument', 'Summons one instrument of the caster&#8217;s choice.'),
new Array('Summon Monster I', 'Conjuration', 'Summoning', 'see text', 'Brd 1, Clr 1, Sor/Wiz 1', 'V, S, F/DF', 'spellsS.html#summon-monster-i', 'Calls extraplanar creature to fight for you.'),
new Array('Summon Monster II', 'Conjuration', 'Summoning', 'see text for summon monster I', 'Brd 2, Clr 2, Sor/Wiz 2', 'V, S, F/DF', 'spellsS.html#summon-monster-ii', 'Calls extraplanar creature to fight for you.'),
new Array('Summon Monster III', 'Conjuration', 'Summoning', 'see text for summon monster I', 'Brd 3, Clr 3, Sor/Wiz 3', 'V, S, F/DF', 'spellsS.html#summon-monster-iii', 'Calls extraplanar creature to fight for you.'),
new Array('Summon Monster IV', 'Conjuration', 'Summoning', 'see text for summon monster I', 'Brd 4, Clr 4, Sor/Wiz 4', 'V, S, F/DF', 'spellsS.html#summon-monster-iv', 'Calls extraplanar creature to fight for you.'),
new Array('Summon Monster IX', 'Conjuration', 'Summoning', 'see text for summon monster I', 'Chaos 9, Clr 9, Evil 9, Good 9, Law 9, Sor/Wiz 9', 'V, S, F/DF', 'spellsS.html#summon-monster-ix', 'Calls extraplanar creature to fight for you.'),
new Array('Summon Monster V', 'Conjuration', 'Summoning', 'see text for summon monster I', 'Brd 5, Clr 5, Sor/Wiz 5', 'V, S, F/DF', 'spellsS.html#summon-monster-v', 'Calls extraplanar creature to fight for you.'),
new Array('Summon Monster VI', 'Conjuration', 'Summoning', 'see text for summon monster I', 'Brd 6, Clr 6, Sor/Wiz 6', 'V, S, F/DF', 'spellsS.html#summon-monster-vi', 'Calls extraplanar creature to fight for you.'),
new Array('Summon Monster VII', 'Conjuration', 'Summoning', 'see text for summon monster I', 'Clr 7, Sor/Wiz 7', 'V, S, F/DF', 'spellsS.html#summon-monster-vii', 'Calls extraplanar creature to fight for you.'),
new Array('Summon Monster VIII', 'Conjuration', 'Summoning', 'see text for summon monster I', 'Clr 8, Sor/Wiz 8', 'V, S, F/DF', 'spellsS.html#summon-monster-viii', 'Calls extraplanar creature to fight for you.'),
new Array('Summon Nature\'s Ally I', 'Conjuration', 'Summoning', '', 'Drd 1, Rgr 1', 'V, S, DF', 'spellsS.html#summon-natures-ally-i', 'Calls creature to fight.'),
new Array('Summon Nature\'s Ally II', 'Conjuration', 'Summoning', '', 'Drd 2, Rgr 2', 'V, S, DF', 'spellsS.html#summon-natures-ally-ii', 'Calls creature to fight.'),
new Array('Summon Nature\'s Ally III', 'Conjuration', 'Summoning', 'see text', 'Drd 3, Rgr 3', 'V, S, DF', 'spellsS.html#summon-natures-ally-iii', 'Calls creature to fight.'),
new Array('Summon Nature\'s Ally IV', 'Conjuration', 'Summoning', 'see text', 'Animal 4, Drd 4', 'V, S, DF', 'spellsS.html#summon-natures-ally-iv', 'Calls creature to fight.'),
new Array('Summon Nature\'s Ally IX', 'Conjuration', 'Summoning', 'see text', 'Drd 9', 'V, S, DF', 'spellsS.html#summon-natures-ally-ix', 'Calls creature to fight.'),
new Array('Summon Nature\'s Ally V', 'Conjuration', 'Summoning', 'see text', 'Drd 5', 'V, S, DF', 'spellsS.html#summon-natures-ally-v', 'Calls creature to fight.'),
new Array('Summon Nature\'s Ally VI', 'Conjuration', 'Summoning', 'see text', 'Drd 6', 'V, S, DF', 'spellsS.html#summon-natures-ally-vi', 'Calls creature to fight.'),
new Array('Summon Nature\'s Ally VII', 'Conjuration', 'Summoning', 'see text', 'Drd 7', 'V, S, DF', 'spellsS.html#summon-natures-ally-vii', 'Calls creature to fight.'),
new Array('Summon Nature\'s Ally VIII', 'Conjuration', 'Summoning', 'see text', 'Animal 8, Drd 8', 'V, S, DF', 'spellsS.html#summon-natures-ally-viii', 'Calls creature to fight.'),
new Array('Summon Swarm', 'Conjuration', 'Summoning', '', 'Brd 2, Drd 2, Sor/Wiz 2', 'V, S, M/DF', 'spellsS.html#summon-swarm', 'Summons swarm of bats, rats, or spiders.'),
new Array('Sunbeam', 'Evocation', '', 'Light', 'Drd 7, Sun 7', 'V, S, DF', 'spellsS.html#sunbeam', 'Beam <a href="#" onClick="openLink(\'abilitiesAndConditions.html#blinded\');return false" style="color: rgb(87, 158, 182);">blinds</a> and deals 4d6 damage.'),
new Array('Sunburst', 'Evocation', '', 'Light', 'Drd 8, Sor/Wiz 8, Sun 8', 'V, S, M/DF', 'spellsS.html#sunburst', 'Blinds all within 10 ft., deals 6d6 damage.'),
new Array('Symbol of Death', 'Necromancy', '', 'Death', 'Clr 8, Sor/Wiz 8', 'V, S, M', 'spellsS.html#symbol-of-death', 'Triggered rune slays nearby creatures.'),
new Array('Symbol of Fear', 'Necromancy', '', 'Fear, Mind-Affecting', 'Clr 6, Sor/Wiz 6', 'V, S, M', 'spellsS.html#symbol-of-fear', 'Triggered rune panics nearby creatures.'),
new Array('Symbol of Insanity', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Clr 8, Sor/Wiz 8', 'V, S, M', 'spellsS.html#symbol-of-insanity', 'Triggered rune renders nearby creatures insane.'),
new Array('Symbol of Pain', 'Necromancy', '', 'Evil', 'Clr 5, Sor/Wiz 5', 'V, S, M', 'spellsS.html#symbol-of-pain', 'Triggered rune wracks nearby creatures with pain.'),
new Array('Symbol of Persuasion', 'Enchantment', 'Charm', 'Mind-Affecting', 'Clr 6, Sor/Wiz 6', 'V, S, M', 'spellsS.html#symbol-of-persuasion', 'Triggered rune charms nearby creatures.'),
new Array('Symbol of Sleep', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Clr 5, Sor/Wiz 5', 'V, S, M', 'spellsS.html#symbol-of-sleep', 'Triggered rune puts nearby creatures into catatonic slumber.'),
new Array('Symbol of Stunning', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Clr 7, Sor/Wiz 7', 'V, S, M', 'spellsS.html#symbol-of-stunning', 'Triggered rune stuns nearby creatures.'),
new Array('Symbol of Weakness', 'Necromancy', '', '', 'Clr 7, Sor/Wiz 7', 'V, S, M', 'spellsS.html#symbol-of-weakness', 'Triggered rune weakens nearby creatures.'),
new Array('Sympathetic Vibration', 'Evocation', '', 'Sonic', 'Brd 6', 'V, S, F', 'spellsS.html#sympathetic-vibration', 'Deals 2d10 damage/round to freestanding structure.'),
new Array('Sympathy', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Drd 9, Sor/Wiz 8', 'V, S, M', 'spellsS.html#sympathy', 'Object or location attracts certain creatures.'),
new Array('Telekinesis', 'Transmutation', '', '', 'Sor/Wiz 5', 'V, S', 'spellsTtoZ.html#telekinesis', 'Moves object, attacks creature, or hurls object or creature.'),
new Array('Telekinetic Sphere', 'Evocation', '', 'Force', 'Sor/Wiz 8', 'V, S, M', 'spellsTtoZ.html#telekinetic-sphere', 'As resilient sphere, but you move sphere telekinetically.'),
new Array('Telepathic Bond', 'Divination', '', '', 'Sor/Wiz 5', 'V, S, M', 'spellsTtoZ.html#telepathic-bond', 'Link lets allies communicate.'),
new Array('Teleport', 'Conjuration', 'Teleportation', '', 'Sor/Wiz 5, Travel 5', 'V', 'spellsTtoZ.html#teleport', 'Instantly transports you as far as 100 miles/level.'),
new Array('Teleport Object', 'Conjuration', 'Teleportation', '', 'Sor/Wiz 7', 'V', 'spellsTtoZ.html#teleport-object', 'As teleport, but affects a touched object.'),
new Array('Teleport, Greater', 'Conjuration', 'Teleportation', '', 'Sor/Wiz 7, Travel 7', 'V', 'spellsTtoZ.html#greater-teleport', 'As teleport, but no range limit and no off-target arrival.'),
new Array('Teleportation Circle', 'Conjuration', 'Teleportation', '', 'Sor/Wiz 9', 'V, M', 'spellsTtoZ.html#teleportation-circle', 'Circle teleports any creature inside to designated spot.'),
new Array('Temporal Stasis', 'Transmutation', '', '', 'Sor/Wiz 8', 'V, S, M', 'spellsTtoZ.html#temporal-stasis', 'Puts subject into suspended animation.'),
new Array('Time Stop', 'Transmutation', '', '', 'Sor/Wiz 9, Trickery 9', 'V', 'spellsTtoZ.html#time-stop', 'You act freely for 1d4+1 rounds.'),
new Array('Tiny Hut', 'Evocation', '', 'Force', 'Brd 3, Sor/Wiz 3', 'V, S, M', 'spellsTtoZ.html#tiny-hut', 'Creates shelter for ten creatures.'),
new Array('Tongues', 'Divination', '', '', 'Brd 2, Clr 4, Sor/Wiz 3', 'V, M/DF', 'spellsTtoZ.html#tongues', 'Speak any language.'),
new Array('Touch of Fatigue', 'Necromancy', '', '', 'Sor/Wiz 0', 'V, S, M', 'spellsTtoZ.html#touch-of-fatigue', 'Touch attack fatigues target.'),
new Array('Touch of Idiocy', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Sor/Wiz 2', 'V, S', 'spellsTtoZ.html#touch-of-idiocy', 'Subject takes 1d6 points of Int, Wis, and Cha damage.'),
new Array('Transformation', 'Transmutation', '', '', 'Sor/Wiz 6', 'V, S, M', 'spellsTtoZ.html#transformation', 'You gain combat bonuses.'),
new Array('Transmute Metal to Wood', 'Transmutation', '', '', 'Drd 7', 'V, S, DF', 'spellsTtoZ.html#transmute-metal-to-wood', 'Metal within 40 ft. becomes wood.'),
new Array('Transmute Mud to Rock', 'Transmutation', '', 'Earth', 'Drd 5, Sor/Wiz 5', 'V, S, M/DF', 'spellsTtoZ.html#transmute-mud-to-rock', 'Transforms two 10-ft. cubes per level.'),
new Array('Transmute Rock to Mud', 'Transmutation', '', 'Earth', 'Drd 5, Sor/Wiz 5', 'V, S, M/DF', 'spellsTtoZ.html#transmute-rock-to-mud', 'Transforms two 10-ft. cubes per level.'),
new Array('Transport via Plants', 'Transmutation', '', '', 'Drd 6', 'V, S', 'spellsTtoZ.html#transport-via-plants', 'Move instantly from one plant to another of the same kind.'),
new Array('Trap the Soul', 'Conjuration', 'Summoning', '', 'Sor/Wiz 8', 'V, S, M, (F); see text', 'spellsTtoZ.html#trap-the-soul', 'Imprisons subject within gem.'),
new Array('Tree Shape', 'Transmutation', '', '', 'Drd 2, Rgr 3', 'V, S, DF', 'spellsTtoZ.html#tree-shape', 'You look exactly like a tree for 1 hour/level.'),
new Array('Tree Stride', 'Conjuration', 'Teleportation', '', 'Drd 5, Rgr 4', 'V, S, DF', 'spellsTtoZ.html#tree-stride', 'Step from one tree to another far away.'),
new Array('True Resurrection', 'Conjuration', 'Healing', '', 'Clr 9', 'V, S, M, DF', 'spellsTtoZ.html#true-resurrection', 'As resurrection, plus remains aren&#8217;t needed.'),
new Array('True Seeing', 'Divination', '', '', 'Clr 5, Drd 7, Knowledge 5, Sor/Wiz 6', 'V, S, M', 'spellsTtoZ.html#true-seeing', 'Lets you see all things as they really are.'),
new Array('True Strike', 'Divination', '', '', 'Sor/Wiz 1', 'V, F', 'spellsTtoZ.html#true-strike', '+20 on your next attack roll.'),
new Array('Undeath to Death', 'Necromancy', '', '', 'Clr 6, Sor/Wiz 6', 'V, S, M/DF', 'spellsTtoZ.html#undeath-to-death', 'Destroys 1d4/level HD of undead (max 20d4).'),
new Array('Undetectable Alignment', 'Abjuration', '', '', 'Brd 1, Clr 2, Pal 2', 'V, S', 'spellsTtoZ.html#undetectable-alignment', 'Conceals alignment for 24 hours.'),
new Array('Unhallow', 'Evocation', '', 'Evil', 'Clr 5, Drd 5', 'V, S, M', 'spellsTtoZ.html#unhallow', 'Designates location as unholy.'),
new Array('Unholy Aura', 'Abjuration', '', 'Evil', 'Clr 8, Evil 8', 'V, S, F', 'spellsTtoZ.html#unholy-aura', '+4 to AC, +4 resistance, and SR 25 against good spells.'),
new Array('Unholy Blight', 'Evocation', '', 'Evil', 'Evil 4', 'V, S', 'spellsTtoZ.html#unholy-blight', 'Damages and sickens good creatures.'),
new Array('Unseen Servant', 'Conjuration', 'Creation', '', 'Brd 1, Sor/Wiz 1', 'V, S, M', 'spellsTtoZ.html#unseen-servant', '<a href="#" onClick="openLink(\'abilitiesAndConditions.html#invisible\');return false" style="color: rgb(87, 158, 182);">Invisible</a> force obeys your commands.'),
new Array('Vampiric Touch', 'Necromancy', '', '', 'Sor/Wiz 3', 'V, S', 'spellsTtoZ.html#vampiric-touch', 'Touch deals 1d6/two levels damage; caster gains damage as hp.'),
new Array('Veil', 'Illusion', 'Glamer', '', 'Brd 6, Sor/Wiz 6', 'V, S', 'spellsTtoZ.html#veil', 'Changes appearance of group of creatures.'),
new Array('Ventriloquism', 'Illusion', 'Figment', '', 'Brd 1, Sor/Wiz 1', 'V, F', 'spellsTtoZ.html#ventriloquism', 'Throws voice for 1 min./level.'),
new Array('Virtue', 'Transmutation', '', '', 'Clr 0, Drd 0, Pal 1', 'V, S, DF', 'spellsTtoZ.html#virtue', 'Subject gains 1 temporary hp.'),
new Array('Vision', 'Divination', '', '', 'Sor/Wiz 7', 'V, S, M, XP', 'spellsTtoZ.html#vision', 'As legend lore, but quicker and strenuous.'),
new Array('Wail of the Banshee', 'Necromancy', '', 'Death, Sonic', 'Death 9, Sor/Wiz 9', 'V', 'spellsTtoZ.html#wail-of-the-banshee', 'Kills one creature/level.'),
new Array('Wall of Fire', 'Evocation', '', 'Fire', 'Drd 5, Fire 4, Sor/Wiz 4', 'V, S, M/DF', 'spellsTtoZ.html#wall-of-fire', 'Deals 2d4 fire damage out to 10 ft. and 1d4 out to 20 ft. Passing through wall deals 2d6 damage +1/level.'),
new Array('Wall of Force', 'Evocation', '', 'Force', 'Sor/Wiz 5', 'V, S, M', 'spellsTtoZ.html#wall-of-force', 'Wall is immune to damage.'),
new Array('Wall of Ice', 'Evocation', '', 'Cold', 'Sor/Wiz 4', 'V, S, M', 'spellsTtoZ.html#wall-of-ice', 'Ice plane creates wall with 15 hp +1/level, or hemisphere can trap creatures inside.'),
new Array('Wall of Iron', 'Conjuration', 'Creation', '', 'Sor/Wiz 6', 'V, S, M', 'spellsTtoZ.html#wall-of-iron', '30 hp/four levels; can topple onto foes.'),
new Array('Wall of Stone', 'Conjuration', 'Creation', 'Earth', 'Clr 5, Drd 6, Earth 5, Sor/Wiz 5', 'V, S, M/DF', 'spellsTtoZ.html#wall-of-stone', 'Creates a stone wall that can be shaped.'),
new Array('Wall of Thorns', 'Conjuration', 'Creation', '', 'Drd 5, Plant 5', 'V, S', 'spellsTtoZ.html#wall-of-thorns', 'Thorns damage anyone who tries to pass.'),
new Array('Warp Wood', 'Transmutation', '', '', 'Drd 2', 'V, S', 'spellsTtoZ.html#warp-wood', 'Bends wood (shaft, handle, door, plank).'),
new Array('Water Breathing', 'Transmutation', '', '', 'Clr 3, Drd 3, Sor/Wiz 3, Water 3', 'V, S, M/DF', 'spellsTtoZ.html#water-breathing', 'Subjects can breathe underwater.'),
new Array('Water Walk', 'Transmutation', '', 'Water', 'Clr 3, Rgr 3', 'V, S, DF', 'spellsTtoZ.html#water-walk', 'Subject treads on water as if solid.'),
new Array('Waves of Exhaustion', 'Necromancy', '', '', 'Sor/Wiz 7', 'V, S', 'spellsTtoZ.html#waves-of-exhaustion', 'Several targets become <a href="#" onClick="openLink(\'abilitiesAndConditions.html#exhausted\');return false" style="color: rgb(87, 158, 182);">exhausted</a>.'),
new Array('Waves of Fatigue', 'Necromancy', '', '', 'Sor/Wiz 5', 'V, S', 'spellsTtoZ.html#waves-of-fatigue', 'Several targets become <a href="#" onClick="openLink(\'abilitiesAndConditions.html#fatigued\');return false" style="color: rgb(87, 158, 182);">fatigued</a>.'),
new Array('Web', 'Conjuration', 'Creation', '', 'Sor/Wiz 2', 'V, S, M', 'spellsTtoZ.html#web', 'Fills 20-ft.-radius spread with sticky spiderwebs.'),
new Array('Weird', 'Illusion', 'Phantasm', 'Fear, Mind-Affecting', 'Sor/Wiz 9', 'V, S', 'spellsTtoZ.html#weird', 'As phantasmal killer, but affects all within 30 ft.'),
new Array('Whirlwind', 'Evocation', '', 'Air', 'Air 8, Drd 8', 'V, S, DF', 'spellsTtoZ.html#whirlwind', 'Cyclone deals damage and can pick up creatures.'),
new Array('Whispering Wind', 'Transmutation', '', 'Air', 'Brd 2, Sor/Wiz 2', 'V, S', 'spellsTtoZ.html#whispering-wind', 'Sends a short message 1 mile/level.'),
new Array('Wind Walk', 'Transmutation', '', 'Air', 'Clr 6, Drd 7', 'V, S, DF', 'spellsTtoZ.html#wind-walk', 'You and your allies turn vaporous and travel fast.'),
new Array('Wind Wall', 'Evocation', '', 'Air', 'Air 2, Clr 3, Drd 3, Rgr 2, Sor/Wiz 3', 'V, S, M/DF', 'spellsTtoZ.html#wind-wall', 'Deflects arrows, smaller creatures, and gases.'),
new Array('Wish', 'Universal', '', '', 'Sor/Wiz 9', 'V, XP', 'spellsTtoZ.html#wish', 'As limited wish, but with fewer limits.'),
new Array('Wood Shape', 'Transmutation', '', '', 'Drd 2', 'V, S, DF', 'spellsTtoZ.html#wood-shape', 'Rearranges wooden objects to suit you.'),
new Array('Word of Chaos', 'Evocation', '', 'Chaotic, Sonic', 'Chaos 7, Clr 7', 'V', 'spellsTtoZ.html#word-of-chaos', 'Kills, confuses, stuns, or deafens nonchaotic subjects.'),
new Array('Word of Recall', 'Conjuration', 'Teleportation', '', 'Clr 6, Drd 8', 'V', 'spellsTtoZ.html#word-of-recall', 'Teleports you back to designated place.'),
new Array('Zone of Silence', 'Illusion', 'Glamer', '', 'Brd 4', 'V, S', 'spellsTtoZ.html#zone-of-silence', 'Keeps eavesdroppers from overhearing conversations.'),
new Array('Zone of Truth', 'Enchantment', 'Compulsion', 'Mind-Affecting', 'Clr 2, Pal 2', 'V, S, DF', 'spellsTtoZ.html#zone-of-truth', 'Subjects within range cannot lie.')
);

